/*******************************************************************************
*
* File:         p8p_demo.c
* Description:  系统测试文件
* Version:      V0.1
* Date:         2020-02-22
* Author:       Tempest
 *******************************************************************************/
#include "p8p_demo.h"
#include "ArmCM0.h"
#include "tau_device_datatype.h"
#include "tau_log.h"
#include "tau_operations.h"
#include "tau_common.h"
#include "tau_delay.h"
#include "hal_dsi_rx_ctrl.h"
#include "hal_dsi_tx_ctrl.h"
#include "hal_swire.h"
#include "hal_timer.h"
#include "hal_system.h"
#include "hal_gpio.h"
#include "test_cfg_global.h"
#include "hal_pwr.h"
#include "hal_pwm.h"
#include "hal_crc.h"

#ifdef LOG_TAG
#undef LOG_TAG
#endif
#define LOG_TAG "p8p"

#if _DEMO_GOOGLE_P8P_EN

/******************** FEATURE开关 ********************/
#define TOUCH_ENABLE                   false    /* Touch转换开关 */
#define RX_START_WITHOUT_RST           true    /* 不等待AP RESET直接启动RX,仅作为调试使用 */
#define RX_WAIT_TEAR_ON                false     /* 等待AP_TEAR_ON */
#define RX_RESOLUTION_CHANGE_ENABLE    true     /* 支持分辨率切换开关, AP存在分辨率切换时需要打开 */
#define RX_READ_HW_ACK                 false    /* AP DCS读命令使用硬件回复 */
#define TX_START_AFTER_APRST           false    /* 等待AP_reset 后做Panel初始化, 用于热拔插电源不稳定导致初始化失败 */
#define TX_USE_CMD_MODE                false    /* command mode输出开关 配置为True时需要把TD TE与 AP TE 接一起*/
#define TX_CMD_MODE_WITHOUT_TE         false    /* 屏端TE直接输出给AP,Scaler不看TE信号,AP每输入一帧输出一帧(C2C 60Hz->60Hz) */
#define AP_SWIRE_OUTPUT                true     /* swire信号输出,OLED项目配置 */
#define ANALOG_PWM_OUTPUT              false     /* 模拟PWM 调光开关 */
#define SHARE_FLASH_ENABLE             false    /* 共享flash开关 */
/*****************************************************/

/******************** 输出屏幕选择 ********************/
#define AMOLED_ICNA3508                1                   /* 4lane FHD Panel */
/*****************************************************/

/****************** 系统相关参数配置 ******************/
#define MAIN_POWER_SELECT              PWR_SEL_VCC           /* 主供电电源选择 */
#define SLEEP_MODE_POWER               PWR_SLEEP_IN_IOV18 //PWR_SLEEP_IN_TP18     /* 息屏电源选择 */
#define SLEEP_MODE_SELECT              PWR_DEEP_SLEEP_MODE //PWR_DEEP_SLEEP_MODE //PWR_NORMAL_SLEEP_MODE //   /* sleep mode 配置 */
#define SWIRE_DEFAULT_PULSE            31  // 41  //31                    /* SWIRE 波形配置 */
#define PWM_FREQUENCY                  30000                 /* PWM输出频率30Khz */
#define PWM_DUTY_STEP                  255                   /* PWM调光阶数255阶 */
/*****************************************************/

/********************RX 基本参数配置*******************/
//AP MIPI数据信息
/* 输入分辨率 */
#define INPUT_WIDTH  1344
#define INPUT_HEIGHT 2992
/* 输入 MIPI lane rate,需要正确配置,可50M step调整 */
#define INPUT_MIPI_LANE_RATE 1600000000
/* 输入图像格式 */
#define INPUT_COLOR_MODE DSI_RGB888
/* 输出数据格式(DSI_DATA_CMD_MODE , DSI_DATA_VIDEO_MODE) */
#define INPUT_DATA_MODE DSI_DATA_CMD_MODE
/* 输入mipi lane数量(DSI_RX_LANE_x     x为1-4) */
#define INPUT_MIPI_LANE_NUM DSI_LANE_4
/* 输入为video mode 时数据格式 */
#define INPUT_VIDEO_MODEL DSI_NONBURST_EVENT
/* 输入虚拟通道(0-3) */
#define INPUT_VC DSI_VC_0
/* 输入的帧率(60/90/120/144Hz) */
#define INPUT_FRAME_RATE DSI_FRAME_RATE_120HZ
/* 输入数据是否DSC压缩 */
#define INPUT_COMPRESS true
/*****************************************************/

/********************TX 基本参数配置*******************/
#if AMOLED_ICNA3508
//almoled NT37280输出MIPI数据信息
/* 输出分辨率配置 */
#define OUTPUT_WIDTH 1080
#define OUTPUT_HEIGHT 2400
/* 输出虚拟通道(0-3) */
#define OUTPUT_VC DSI_VC_0
/* 输出mipi lane数量(DSI_RX_LANE_x     x为1-4) */
#define OUTPUT_LANE_NUMBER DSI_LANE_4
/* 输出数据格式(DSI_DATA_CMD_MODE , DSI_DATA_VIDEO_MODE) */
#if TX_USE_CMD_MODE
#define OUTPUT_DATA_MODE DSI_DATA_CMD_MODE
#else
#define OUTPUT_DATA_MODE DSI_DATA_VIDEO_MODE
#endif
/* 输出为video mode时的数据格式 */
#define OUTPUT_VIDEO_MODEL DSI_BURST_MODE
/* 输出 VSA */
#define OUTPUT_VSA  1 //1
/* 输出 VBP */
#define OUTPUT_VBP  19  //19
/* 输出 VBP */
#define OUTPUT_VFP  12  //12
/* 输出 VSA */
#define OUTPUT_HSA  1
/* 输出 HBP */
#define OUTPUT_HBP  27
/* 输出 HFP */
#define OUTPUT_HFP  77
/* 初始化模式命令传输类型 LP/HS */
#define TX_INIT_TYPE            DSI_CMD_TX_LP
#endif
/******************************************************/

#if TOUCH_ENABLE
#include "app_tp_transfer.h"
#endif

/* 全局handle */
static hal_dsi_rx_ctrl_handle_t *g_rx_ctrl_handle = NULL;
static hal_dsi_tx_ctrl_handle_t *g_tx_ctrl_handle = NULL;

/* 屏初始化完成标志位 */
static bool panel_display_done = false;
static bool sg_system_resume = false;
static bool sg_system_suspend = false;
static bool sg_exit_idle_mode_flag = false;

static volatile bool g_resolution_change = false;
static uint32_t pps_renew_flag = 0;
static uint32_t pwr_rst_flag = 0;

#if RX_WAIT_TEAR_ON
static bool sg_ap_set_tear_on = false;
#endif
#if TX_START_AFTER_APRST
static bool sg_tx_start_in_process = false;
#endif

uint16_t rd_51_val,rd_51_val2;

/* AP reset 回调函数声明 */
static void ap_rstn_pull_high_cb(void *data);
static void ap_rstn_pull_down_cb(void *data);
static void app_mipi_rx_start_cb(void *data);


/*************************DCS 命令处理函数 BEGIN*************************/
#if RX_READ_HW_ACK
/**
* @brief  配置AP硬件回读
* @param  none
* @retval none
*/
static void app_set_dcs_hw_ack()
{
    hal_dsi_rx_ctrl_set_auto_ack(g_rx_ctrl_handle, HAL_RX_QRESP_CODE0, DSI_ACK_DT_DCS_SHORT_RESPONSE_1B, 0xFA, 1, 0x00);
}
#endif
/**
* @brief  ap 读回调函数
* @param  handler：rx_ctrl_handle
*         dcs_packet: dcs 命令
* @retval true/false
*/
static bool ap_dcs_read(uint8_t data_type, uint8_t dcs_cmd, uint8_t param)
{
 	if (dcs_cmd == 0x04)
	{
		hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
									 DSI_ACK_DT_DCS_LONG_RESPONSE,
									 DSI_VC_0,
									 3, 0x0A,0x60,0x20);
	}
	else if (dcs_cmd == 0xa1)
	{
		hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
									 DSI_ACK_DT_DCS_LONG_RESPONSE,
									 DSI_VC_0,
									 13, 0x0C,0x21,0x0C,0xC6,0x01,0xF3,0xAA,0x11,0x06,0x2B,0x25,0x21,0xF6);
	}
	else if (dcs_cmd == 0xDA)
	{
		hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
									 DSI_ACK_DT_DCS_SHORT_RESPONSE_1B,
									 DSI_VC_0,
									 1, 0x0A);
	}
	else if (dcs_cmd == 0xDB)
	{
		hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
									 DSI_ACK_DT_DCS_SHORT_RESPONSE_1B,
									 DSI_VC_0,
									 1, 0x68);
	}
	else if (dcs_cmd == 0xDC)
	{
		hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
									 DSI_ACK_DT_DCS_SHORT_RESPONSE_1B,
									 DSI_VC_0,
									 1, 0x07);
	}
	else if (dcs_cmd == 0xD6)
	{
		hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
									 DSI_ACK_DT_DCS_LONG_RESPONSE,
									 DSI_VC_0,
									 5, 0xF0, 0xEA, 0x85, 0x61, 0x86);
	}
	else
	{
		uint32_t return_size = hal_dsi_rx_ctrl_get_max_ret_size(g_rx_ctrl_handle);
		hal_dsi_rx_ctrl_send_ack_cmd(g_rx_ctrl_handle,
									 DSI_ACK_DT_DCS_SHORT_RESPONSE_1B,
									 DSI_VC_0,
									 1, 0);
		TAU_LOGD("r[%x] [%d] err!!!!!!\n", dcs_cmd, return_size);
	}
	
//	TAU_LOGD("r %x\n",dcs_cmd);
	return true;	
}

uint8_t pps[128] = {0x11,0x00,0x00,0x89,0x30,0x80,0x0B,0xB0,
					0x05,0x40,0x00,0xBB,0x02,0xA0,0x02,0xA0,
					0x02,0x00,0x02,0x50,0x00,0x20,0x14,0x39,
					0x00,0x09,0x00,0x0C,0x00,0x85,0x00,0x70,
					0x18,0x00,0x10,0xF0,0x03,0x0C,0x20,0x00,
					0x06,0x0B,0x0B,0x33,0x0E,0x1C,0x2A,0x38,
					0x46,0x54,0x62,0x69,0x70,0x77,0x79,0x7B,
					0x7D,0x7E,0x01,0x02,0x01,0x00,0x09,0x40,
					0x09,0xBE,0x19,0xFC,0x19,0xFA,0x19,0xF8,
					0x1A,0x38,0x1A,0x78,0x1A,0xB6,0x2A,0xF6,
					0x2B,0x34,0x2B,0x74,0x3B,0x74,0x6B,0xF4,
					0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
					0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
					0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
					0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
					0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00};
uint8_t pps_fhd[128] = {0x11,0x00,0x00,0x89,0x30,0x80,0x08,0xC4,
						0x03,0xF0,0x00,0xBB,0x01,0xF8,0x01,0xF8,
						0x02,0x00,0x01,0xF8,0x00,0x20,0x11,0x82,
						0x00,0x07,0x00,0x0C,0x00,0x85,0x00,0x96,
						0x18,0x00,0x10,0xF0,0x03,0x0C,0x20,0x00,
						0x06,0x0B,0x0B,0x33,0x0E,0x1C,0x2A,0x38,
						0x46,0x54,0x62,0x69,0x70,0x77,0x79,0x7B,
						0x7D,0x7E,0x01,0x02,0x01,0x00,0x09,0x40,
						0x09,0xBE,0x19,0xFC,0x19,0xFA,0x19,0xF8,
						0x1A,0x38,0x1A,0x78,0x1A,0xB6,0x2A,0xF6,
						0x2B,0x34,0x2B,0x74,0x3B,0x74,0x6B,0xF4,
						0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
						0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
						0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
						0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
						0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00};


#if RX_RESOLUTION_CHANGE_ENABLE
/* PPS update callback 用于分辨率切换case */
static bool pps_update_handle(uint8_t *pps, uint8_t size, uint32_t pic_width, uint32_t pic_height)
{
//			for (uint8_t i =0; i< 128; i++)
//		{
//	     TAU_LOGD("PPS_0A[i]=[0x%02X]\n",i,pps[i]);
//		}

    /* AVDD 上电, 用于解决息屏开屏PPS不更新问题 */
 //   hal_gpio_set_output_data(IO_PAD_AP_PWMEN, IO_LVL_HIGH);
    if (pic_width != g_rx_ctrl_handle->base_info.src_w || pic_height != g_rx_ctrl_handle->base_info.src_h)
    {
        hal_dsi_tx_ctrl_set_tear_mode(g_tx_ctrl_handle, TE_USER_MODE);
        /* PPS Update 且分辨率发生变化 */
        g_rx_ctrl_handle->base_info.src_w = pic_width;
        g_rx_ctrl_handle->base_info.src_h = pic_height;
        /* 注意部分基板更新PPS前不发 Compression Mode Command的情况 */
        g_rx_ctrl_handle->compress_en = true;  
        g_resolution_change           = true;
		if(pic_width > 720)
		{
			g_tx_ctrl_handle->base_info.src_w = pic_width;
			g_tx_ctrl_handle->base_info.src_h = pic_height;
		}
//        hal_dsi_tx_ctrl_write_cmd(0x05, 0, 1, 0x22); // ic刷黑处理
//        delayMs(5);

//		hal_dsi_rx_ctrl_pre_init_pps(g_rx_ctrl_handle, pps, 128);
		hal_dsi_rx_ctrl_toggle_resolution(g_rx_ctrl_handle);
 //       hal_dsi_tx_ctrl_write_cmd(0x05, 0, 1, 0x13); // 退出刷黑
    }
	    hal_dsi_tx_ctrl_set_tear_mode(g_tx_ctrl_handle, TE_60HZ_MODE);
    //TAU_LOGD("PPS Update[%d][%d] [%d][%d]\n", pic_width, pic_height, g_rx_ctrl_handle->base_info.src_w, g_rx_ctrl_handle->base_info.src_h);
    return true;
}
#endif



/**
* @brief  ap display on处理函数
* @param  handler：rx_ctrl_handle
*         dcs_packet: dcs 命令
* @retval true/false
*/
static bool ap_dcs_set_display_on(hal_dsi_rx_ctrl_handle_t *handler, hal_dcs_packet_t *dcs_packet)
{
	    
    if(g_resolution_change)
	{
		hal_dsi_rx_ctrl_pre_init_pps(g_rx_ctrl_handle, pps_fhd, 128);
		hal_dsi_rx_ctrl_toggle_resolution(g_rx_ctrl_handle);
		g_resolution_change = false;
		TAU_LOGD("pps_update_1\r\n");
	}
//    TAU_LOGD("disp on");
//	if (start_display_on == false){
		hal_dsi_tx_ctrl_write_cmd(0x05, 0, 2, 0x29);
//	}
    TAU_LOGD("disp on \n");
    return true;
}


void REG_51_OFF_output(uint16_t REG_51_VALUE)
{
	uint8_t i;
	uint16_t REG_51;



		for (i =0; i< 50; i++)
		{
			REG_51=REG_51_VALUE*(50-i)/50;
			hal_dsi_tx_ctrl_write_cmd(0x39, 0, 3, 0x51, REG_51>>8, REG_51&0x00FF);;
			delayMs(17);
	//	    TAU_LOGD("reg_51_off[0x%04X]\n",REG_51);
		}

}

/**
* @brief  ap display off处理函数
* @param  handler：rx_ctrl_handle
*         dcs_packet: dcs 命令
* @retval true/false
*/
static bool ap_dcs_set_display_off(hal_dsi_rx_ctrl_handle_t *handler, hal_dcs_packet_t *dcs_packet)
{
#if ANALOG_PWM_OUTPUT
    hal_pwm_enable(false);
#endif

    TAU_LOGD("disp off %d\n", panel_display_done);
    return true;
}


/*****************************************************************************
*GPIO发送swire波形
*flag:  =0, SWIRE=0;  =1,仅发送SWIRE信号; =2, 先置高再发SWIRE信号
*num: 发几个脉冲
*注意FLAG=1时无GPIO初始化!!!!!!
*****************************************************************************/
void Gpio_swire_output(uint8_t flag, uint8_t num)
{
	uint8_t ii;

	if (flag)
	{
		if (flag ==2)
		{
			hal_gpio_init_output(IO_PAD_AP_SWIRE, IO_LVL_HIGH);	  
			delayMs(2);
		}
		for (ii =0; ii< num; ii++)
		{
			hal_gpio_set_output_data(IO_PAD_AP_SWIRE, IO_LVL_LOW);
			delayUs(10);
			hal_gpio_set_output_data(IO_PAD_AP_SWIRE, IO_LVL_HIGH);
			delayUs(9);
		}
	}
	else
	{
		hal_gpio_init_output(IO_PAD_AP_SWIRE, IO_LVL_LOW);	  
	}
}



/**
* @brief  ap enter sleep mode处理函数
* @param  handler：rx_ctrl_handle
*         dcs_packet: dcs 命令
* @retval true/false
*/
static bool ap_dcs_set_enter_sleep_mode(hal_dsi_rx_ctrl_handle_t *handler, hal_dcs_packet_t *dcs_packet)
{
	hal_dsi_tx_ctrl_write_cmd(0x05, 0, 1, 0x28);
	hal_dsi_tx_ctrl_set_tear_mode(g_tx_ctrl_handle, TE_STOP_MODE);
	delayMs(10);

	// delayMs(10);
#if AP_SWIRE_OUTPUT
    /* Swire close */
   hal_swire_enable(false);
		delayMs(10);
	hal_dsi_tx_ctrl_write_cmd(0x05, 0, 1, 0x10);
	   delayMs(20);
    /* AVDD_EN close*/
    hal_gpio_set_output_data(IO_PAD_AP_PWMEN, IO_LVL_LOW);
#endif
    /* Wait AP reset down*/
    hal_gpio_set_ap_reset_int(ENABLE, ap_rstn_pull_down_cb, DETECT_LOW_LVL);
 // sg_system_suspend=true;
 TAU_LOGD("enter sleep mode\n");
// delayMs(500);
    return true;
}

/**
* @brief  ap exit sleep mode处理函数
* @param  handler：rx_ctrl_handle
*         dcs_packet: dcs 命令
* @retval true/false
*/
static bool ap_dcs_set_exit_sleep_mode(hal_dsi_rx_ctrl_handle_t *handler, hal_dcs_packet_t *dcs_packet)
{
//#if AP_SWIRE_OUTPUT
//    /* AVDD 上电, 用于解决息屏开屏PPS不更新问题 */
//    hal_gpio_set_output_data(IO_PAD_AP_PWMEN, IO_LVL_HIGH);
//#endif

#if TX_START_AFTER_APRST
    if (panel_display_done == false)
    {
        sg_tx_start_in_process = true;
    }
#endif

    TAU_LOGD("exit sleep mode \n");

    return true;
}



/**
* @brief  调光处理函数
* @param  handler：rx_ctrl_handle
*         dcs_packet: dcs 命令
* @retval true/false
*/

uint8_t value_51H,value_51L;
static bool reg53_E8_fg=0;
static bool ap_dcs_set_backlight(hal_dsi_rx_ctrl_handle_t *handler, hal_dcs_packet_t *dcs_packet)
{	
	//手机端0xC4~CEB(2043) 映射0x9FF
#if 0
	value_51H = dcs_packet->packet_param[0];
	value_51L = dcs_packet->packet_param[1];
	hal_dsi_tx_ctrl_write_cmd(0x39, 0, 3, 0x51, value_51H, value_51L);
#else
		rd_51_val = dcs_packet->packet_param[0];
	rd_51_val <<=8;
	rd_51_val |= dcs_packet->packet_param[1];

//	rd_51_val2 = (rd_51_val-0x04)*2555/2043+0x04;   //0x9FF max
	if((rd_51_val >=0x00)&&(rd_51_val <= 0xFFF) ){
	
	  rd_51_val2 = (rd_51_val-0xC4)*2555/3889+0x04;   //0x9FF max
	
	}
	else if(rd_51_val >0xFFF) {
	
	  rd_51_val2 = 0x9FF; 
	
	}
		hal_dsi_tx_ctrl_write_cmd(0x39, 0, 3, 0x51, rd_51_val2>>8, rd_51_val2&0x00FF);
#endif
	// TAU_LOGD("AP_51[0x%04X],IC_51[0x%04X]\n",rd_51_val,rd_51_val2);	
    return true;
}

#if RX_WAIT_TEAR_ON
/**
* @brief  ap set tear on 处理函数
* @param  handler：rx_ctrl_handle
*         dcs_packet: dcs 命令
* @retval true/false
*/
static bool ap_dcs_set_tear_on(hal_dsi_rx_ctrl_handle_t *handler, hal_dcs_packet_t *dcs_packet)
{
    TAU_LOGD("ap_set_tear_on\n");
    sg_ap_set_tear_on = true;
    if (panel_display_done == false)
    {
        TAU_LOGD("gen a tear\n");
        hal_dsi_tx_ctrl_gen_a_tear_signal();
    }
    else
    {
        hal_dsi_tx_ctrl_set_tear_mode(g_tx_ctrl_handle, TE_60HZ_MODE);
    }
    return true;
}

/**
* @brief  ap set tear off 处理函数
* @param  handler：rx_ctrl_handle
*         dcs_packet: dcs 命令
* @retval true/false
*/
static bool ap_dcs_set_tear_off(hal_dsi_rx_ctrl_handle_t *handler, hal_dcs_packet_t *dcs_packet)
{
    TAU_LOGD("ap_set_tear_off \n");
    sg_ap_set_tear_on = false;
    hal_dsi_tx_ctrl_set_tear_mode(g_tx_ctrl_handle, TE_USER_MODE);
    return true;
}
#endif

/**
* @brief  护眼模式回调函数
* @param  rx_ctrl_handle: dsi rx handle;
*         dcs packet: dcs_packet
* @retval true/false
*/
static bool ap_dcs_set_exit_idle_mode(hal_dsi_rx_ctrl_handle_t *handler, hal_dcs_packet_t *dcs_packet)
{
    sg_exit_idle_mode_flag = true;
    hal_dsi_rx_ctrl_set_hw_cmd_filter(g_rx_ctrl_handle, HAL_RX_DCS_FILTER_B, 0x2C, 0x2C);
    TAU_LOGD("exit idle mode,skip 0x2C\n");
    return true;
}

#define TE_TIMER    TIMER_NUM2
static void soft_te_timer_cb(void *data)
{
    /*
        S8 的屏接的是TP1.8V, AC 启动后需要等到TP1.8 起来后再初始化屏, 所以在TP 起来前需要通过软件产生TE给手机，避免手机卡死
    */
//    if (panel_display_done == false)
//    {
        hal_dsi_tx_ctrl_gen_a_tear_signal();
        hal_timer_start(TE_TIMER, 8, soft_te_timer_cb, NULL);
//    }
//    else
//    {
//        hal_dsi_rx_ctrl_set_hw_tear_mode(g_rx_ctrl_handle);
//    }
}

static void soft_te_timer_init()
{
//    TAU_LOGD("soft_te_timer_init");
    hal_dsi_tx_ctrl_set_tear_mode(g_tx_ctrl_handle,TE_USER_MODE);
    hal_timer_init(TE_TIMER);
    hal_timer_start(TE_TIMER, 1, soft_te_timer_cb, NULL);
}

/**
* @brief  帧率切换处理函数
* @param  handler：rx_ctrl_handle
*         dcs_packet: dcs 命令
* @retval true/false
*/
static bool ap_dcs_set_frame_change(hal_dsi_rx_ctrl_handle_t *handler, hal_dcs_packet_t *dcs_packet)
{
    if (dcs_packet->param_length == 1)
    {
        if (dcs_packet->packet_param[0] == 0x18)
        {
		//	hal_dsi_tx_ctrl_set_tear_mode(g_tx_ctrl_handle,TE_USER_MODE);
            hal_dsi_tx_ctrl_set_tear_mode(g_tx_ctrl_handle, TE_60HZ_MODE);
        }
        else 
        {
		//	soft_te_timer_init();
           hal_dsi_tx_ctrl_set_tear_mode(g_tx_ctrl_handle, TE_120HZ_MODE);
        }
    }
  //  TAU_LOGD("frame_change %x ,size %d, data %d\n", dcs_packet->dcs_command, dcs_packet->param_length, dcs_packet->packet_param[0]);
    return true;
}

static bool ap_set_FPS_53(hal_dsi_rx_ctrl_handle_t *handler, hal_dcs_packet_t *dcs_packet)
{
	uint8_t value_53 =0;	
	
    value_53 =  dcs_packet->packet_param[0]; 

	if(value_53 == 0x30)  // AP FPS ON
	{
    
        hal_dsi_tx_ctrl_write_cmd( 0x39, 0, 4, 0x97, 0x11, 0xCF, 0xFF);  // DDIC FPS ON

	}
	else if(value_53 == 0x20)  // AP FPS OFF
	{

        hal_dsi_tx_ctrl_write_cmd( 0x39, 0, 4, 0x97, 0x00, 0xCF, 0xFF); // DDIC FPS OFF

        
	}

//   	TAU_LOGD("B1[%x]", value_b1);
    return true;
}

/*************************DCS 命令处理函数 END*************************/

/* 客制化DCS command 处理函数表格 */
static const hal_dcs_execute_entry_t g_cus_rx_dcs_execute_table[] =
{
    {DCS_SET_DISPLAY_ON, ap_dcs_set_display_on, false},
    {DCS_SET_DISPLAY_OFF, ap_dcs_set_display_off, true},
    {0x51, ap_dcs_set_backlight, false},
	{0x53, ap_set_FPS_53, true},  //FPS Switch: P6P-0xB1; P7P-0x53
    {DCS_ENTER_SLEEP_MODE, ap_dcs_set_enter_sleep_mode, true},
    {DCS_EXIT_SLEEP_MODE, ap_dcs_set_exit_sleep_mode, true},
    {0x60, ap_dcs_set_frame_change, true},
#if RX_WAIT_TEAR_ON
    {DCS_SET_TEAR_ON, ap_dcs_set_tear_on, true},
    {DCS_SET_TEAR_OFF, ap_dcs_set_tear_off, true},
#endif
    {0, NULL, false}                        //{0,NULL,false} 数组最后一个固定成员，作为table结尾的判断标准
};

/**
* @brief  panel reset
* @param  none
* @retval none
*/
static void app_tx_panel_reset(void)
{
#if SHARE_FLASH_ENABLE
    hal_flash_share_mode(true);
#endif
    hal_gpio_set_output_data(IO_PAD_TD_RSTN, IO_LVL_HIGH);
    delayMs(10);
    hal_gpio_set_output_data(IO_PAD_TD_RSTN, IO_LVL_LOW);
    delayMs(10);
    hal_gpio_set_output_data(IO_PAD_TD_RSTN, IO_LVL_HIGH);
    delayMs(40);
}

#if PANEL_INIT_CODE_ARRAY
static void send_panel_init_code(uint32_t size, uint8_t * data)
{
	uint32_t data_offeset = 0;
	uint8_t data_type;
	uint8_t vc;
	uint8_t data_size;
	uint8_t * p_data;

	while(data_offeset < size)
	{
		data_type = data[data_offeset];
		vc = data[data_offeset + 1];
		data_size = data[data_offeset + 2];
		p_data = &data[data_offeset + 3];
		hal_dsi_tx_ctrl_write_array_cmd(data_type, vc, data_size, p_data);
		data_offeset = data_offeset + data_size + 3;
     delayUs(50);
	}
}

const uint8_t panel_init_code[] = {
#if 1
0x39,0,3,0x9C,0xA5,0xA5,
0x39,0,3,0xFD,0x5A,0x5A,
0x39,0,2,0x9F,0x0F,
0x39,0,2,0xB3,0x00,
0x39,0,2,0xD7,0x11,
0x39,0,2,0x9F,0x01,
0x39,0,4,0xB2,0x5A,0x04,0xAF,
0x39,0,36,0xB3,0x00,0xBA,0x00,0x14,0x0C,0x22,0x00,0xBA,0x30,0x14,0x2C,0x00,0x00,0xBA,0x90,0x14,0x4C,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xBA,0x00,0x14,0x0C,0x44,0x1C,0x1C,0x1C,0x1C,0x1C,
0x39,0,19,0xCD,0x06,0x1F,0x1F,0x06,0x00,0x09,0x00,0x96,0x1F,0x03,0x28,0x00,0x96,0x1F,0x09,0x46,0x00,0x96,
0x39,0,2,0xD0,0x01,
0x39,0,3,0xE2,0x46,0x20,
0x39,0,3,0xEA,0x04,0x0B,
0x39,0,9,0xEE,0x40,0x38,0x28,0x28,0x28,0x28,0x28,0xC2,//add for ICNA5608
0x39,0,2,0x9F,0x02,
0x39,0,26,0xB2,0x00,0xC9,0x32,0x10,0x11,0x12,0x12,0x00,0x08,0x78,0x21,0x11,0x14,0x13,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x21,0x21,0x11,0x1A,
0x39,0,14,0xB4,0x00,0x00,0x8C,0x00,0x00,0x00,0x00,0x00,0x25,0x25,0x25,0x25,0x25,
0x39,0,7,0xB5,0x00,0x30,0x30,0x30,0x30,0x2A,
0x39,0,20,0xB6,0x05,0x00,0x00,0x11,0x11,0x11,0x1C,0x08,0x1C,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,
0x39,0,17,0xB7,0x00,0x00,0x00,0x00,0x00,0x15,0x00,0x06,0x06,0x03,0x06,0x06,0x03,0x06,0x06,0x03,
0x39,0,14,0xB8,0x00,0x00,0x00,0x73,0x28,0x73,0x28,0x73,0x28,0x73,0x28,0x73,0x28,
0x39,0,9,0xB9,0x00,0x00,0x50,0x00,0x00,0x0F,0x0F,0x00,
0x39,0,14,0xBA,0x0E,0xFF,0xFF,0xFF,0x00,0x54,0x00,0x44,0x04,0x44,0x04,0x04,0x00,
0x39,0,26,0xBB,0x00,0x5A,0x91,0x91,0x5A,0x00,0x5A,0x91,0x91,0x5A,0x00,0x5A,0x91,0x91,0x5A,0x00,0x5A,0x91,0x91,0x5A,0x00,0x3C,0x78,0x78,0x3C,
0x39,0,5,0xBE,0x5B,0x17,0x04,0x5B,
0x39,0,17,0xBF,0x0C,0x8F,0xFF,0x10,0x00,0x07,0x00,0x0A,0x01,0x20,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,17,0xC1,0x05,0x21,0x22,0x1D,0x1F,0x1E,0x20,0x01,0x30,0x31,0x32,0x33,0x3D,0x3D,0x3D,0x3D,
0x39,0,17,0xC2,0x05,0x21,0x22,0x1D,0x1F,0x1E,0x20,0x01,0x30,0x31,0x32,0x33,0x3D,0x3D,0x3D,0x3D,
0x39,0,10,0xC3,0x11,0x60,0x00,0x40,0x00,0x40,0x00,0x00,0x00,
0x39,0,26,0xC4,0x00,0x0C,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x00,0x1F,0x1F,0x00,0x00,0x0D,0x00,0x00,0x00,0x00,
0x39,0,17,0xD2,0x00,0x00,0x13,0x00,0x00,0x13,0x00,0x00,0x17,0x00,0x00,0x17,0x00,0x00,0x17,0x00,
0x39,0,14,0xC7,0x00,0x04,0x04,0x04,0x04,0x00,0x04,0x04,0x04,0x04,0x00,0x04,0x04,
0x39,0,14,0xC8,0x00,0xB1,0xB1,0xB1,0xB1,0x00,0xB1,0xB1,0xB1,0xB1,0x00,0xB1,0xB1,
0x39,0,27,0xC6,0x00,0x00,0x0f,0x00,0x00,0x11,0x00,0x00,0x00,0x90,0x00,0x00,0x00,0x00,0x08,0x00,0x02,0x00,0x00,0x00,0x00,0x00,0x55,0x01,0x01,0x00,
0x39,0,27,0xCB,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x90,0x92,0x90,0x92,0x00,0x90,0x92,0x90,0x92,0x00,0x90,0x92,
0x39,0,27,0xCC,0x00,0x76,0xff,0x76,0xff,0x00,0x76,0xff,0x76,0xff,0x00,0x76,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,19,0xD7,0x4D,0xC3,0x20,0x7A,0x33,0x00,0x02,0x02,0x00,0xF7,0xF7,0xF4,0xA9,0xA9,0xAE,0xF0,0x00,0x00,
0x39,0,41,0xD8,0x00,0x04,0x76,0x22,0xFF,0x00,0x04,0x76,0x22,0xFF,0x00,0x04,0x76,0x22,0xFF,0x00,0x04,0x76,0x22,0xFF,0x00,0x04,0x76,0x22,0xFF,0x90,0x76,0xFF,0x90,0x76,0xFF,0x90,0x76,0xFF,0x90,0x76,0xFF,0x90,0x76,0xFF,
0x39,0,12,0xD9,0x10,0x40,0x10,0x00,0x10,0x00,0x10,0x00,0x10,0x00,0x10,
0x39,0,4,0xE0,0x00,0x00,0x60,
0x39,0,6,0xE1,0x43,0x00,0x11,0x60,0x0D,
0x39,0,51,0xE2,0x15,0x00,0x39,0x42,0x24,0x15,0x00,0x39,0x42,0x24,0x15,0x00,0x39,0x42,0x24,0x15,0x00,0x39,0x42,0x24,0x15,0x00,0x39,0x42,0x24,0x15,0x00,0x39,0x42,0x24,0x15,0x00,0x39,0x42,0x24,0x15,0x00,0x39,0x42,0x24,0x15,0x00,0x39,0x42,0x24,0x15,0x00,0x39,0x42,0x24,
0x39,0,4,0xED,0x00,0x01,0x80,
0x39,0,18,0xEE,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x30,0x88,0x88,0x29,0x00,0x00,0x00,0x00,
0x39,0,6,0xEF,0x00,0x85,0x88,0x87,0x87,
0x39,0,2,0x9F,0x03,
0x39,0,33,0xB2,0x11,0x00,0x00,0x89,0x30,0x80,0x09,0x60,0x04,0x38,0x00,0x0C,0x02,0x1C,0x02,0x1C,0x02,0x00,0x02,0x0E,0x00,0x20,0x01,0x1F,0x00,0x07,0x00,0x0C,0x08,0xBB,0x08,0x7A,
0x39,0,33,0xB3,0x18,0x00,0x10,0xF0,0x03,0x0C,0x20,0x00,0x06,0x0B,0x0B,0x33,0x0E,0x1C,0x2A,0x38,0x46,0x54,0x62,0x69,0x70,0x77,0x79,0x7B,0x7D,0x7E,0x01,0x02,0x01,0x00,0x09,0x40,
0x39,0,25,0xB4,0x09,0xBE,0x19,0xFC,0x19,0xFA,0x19,0xF8,0x1A,0x38,0x1A,0x78,0x1A,0xB6,0x2A,0xF6,0x2B,0x34,0x2B,0x74,0x3B,0x74,0x6B,0xF4,
0x39,0,2,0xC0,0x11,
0x39,0,2,0xC1,0x82,
0x39,0,3,0xC2,0x00,0xC0,
0x39,0,6,0xC6,0x11,0x00,0x00,0x01,0x01,
0x39,0,2,0xE2,0x01,
0x39,0,2,0x9F,0x04,
0x39,0,4,0xB2,0x01,0x80,0x00,
0x39,0,19,0xB3,0x00,0x00,0x10,0x00,0x30,0x50,0x00,0x70,0xB0,0x00,0xD0,0xF0,0x11,0x30,0x70,0x12,0xF0,0x70,
0x39,0,21,0xB4,0x23,0xF0,0x70,0x34,0xF0,0xF0,0x67,0xF0,0xF0,0x8A,0xF0,0xF0,0xCD,0xF0,0xF0,0xEF,0xF0,0xF0,0x0F,0xFF,
0x39,0,8,0xB6,0x01,0x20,0x00,0x0F,0xF0,0x10,0x06,
0x39,0,3,0xB9,0x91,0xC1,
0x39,0,3,0xBA,0x01,0x00,
0x39,0,10,0xBB,0x00,0x00,0x08,0x00,0x00,0x00,0xF2,0x00,0x00,
0x39,0,41,0xC1,0x0F,0xFF,0x07,0xFF,0x03,0x33,0x01,0x47,0x01,0x46,0x00,0xCD,0x00,0x66,0x00,0x3A,0x00,0x14,0x00,0x08,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,21,0xC2,0x03,0xFF,0x01,0xFF,0x00,0x00,0x00,0x00,0x03,0xFF,0x01,0xFF,0x00,0x00,0x00,0x00,0x03,0xFF,0x01,0xFF,
0x39,0,4,0xC3,0x00,0x08,0xB8,
0x39,0,20,0xC5,0x00,0x20,0x88,0x41,0xCF,0x4F,0x4F,0x00,0x48,0x53,0x29,0x21,0x28,0x2A,0x05,0x2F,0x00,0x20,0x0F,
0x39,0,37,0xC6,0x4B,0x00,0x90,0x00,0x02,0xD5,0x00,0x02,0xCB,0x01,0x10,0x43,0x00,0x0A,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,5,0xC8,0x48,0x48,0x53,0x53,
0x39,0,3,0xC9,0x88,0x88,
0x39,0,41,0xCC,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,
0x39,0,51,0xCD,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,
0x39,0,41,0xCE,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,
0x39,0,51,0xCF,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,
0x39,0,41,0xD0,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,
0x39,0,51,0xD1,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,
0x39,0,41,0xD2,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,
0x39,0,51,0xD3,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,
0x39,0,41,0xD4,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,
0x39,0,51,0xD5,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,
0x39,0,41,0xD6,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,
0x39,0,51,0xD7,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,
0x39,0,41,0xD8,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,
0x39,0,51,0xD9,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,
0x39,0,41,0xDD,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,
0x39,0,51,0xDE,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,
0x39,0,41,0xDF,0x23,0x15,0x0F,0x0B,0x0B,0x0B,0x0B,0x0B,0x0B,0x0B,0x0B,0x0B,0x0B,0x0B,0x0B,0x0B,0x0B,0x0B,0x0B,0x0B,0x26,0x18,0x12,0x0E,0x0E,0x0E,0x0E,0x0E,0x0E,0x0E,0x0E,0x0E,0x0E,0x0E,0x0E,0x0E,0x0E,0x0E,0x0E,0x0E,
0x39,0,51,0xE0,0x28,0x1A,0x14,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x28,0x1A,0x14,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,
0x39,0,41,0xE1,0x23,0x15,0x0F,0x0B,0x0B,0x0B,0x0B,0x0B,0x0B,0x0B,0x0B,0x0B,0x0B,0x0B,0x0B,0x0B,0x0B,0x0B,0x0B,0x0B,0x26,0x18,0x12,0x0E,0x0E,0x0E,0x0E,0x0E,0x0E,0x0E,0x0E,0x0E,0x0E,0x0E,0x0E,0x0E,0x0E,0x0E,0x0E,0x0E,
0x39,0,51,0xE2,0x28,0x1A,0x14,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x28,0x1A,0x14,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,
0x39,0,41,0xE3,0x23,0x15,0x0F,0x0B,0x0B,0x0B,0x0B,0x0B,0x0B,0x0B,0x0B,0x0B,0x0B,0x0B,0x0B,0x0B,0x0B,0x0B,0x0B,0x0B,0x26,0x18,0x12,0x0E,0x0E,0x0E,0x0E,0x0E,0x0E,0x0E,0x0E,0x0E,0x0E,0x0E,0x0E,0x0E,0x0E,0x0E,0x0E,0x0E,
0x39,0,51,0xE4,0x28,0x1A,0x14,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x28,0x1A,0x14,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,
0x39,0,41,0xE5,0x23,0x15,0x0F,0x0B,0x0B,0x0B,0x0B,0x0B,0x0B,0x0B,0x0B,0x0B,0x0B,0x0B,0x0B,0x0B,0x0B,0x0B,0x0B,0x0B,0x26,0x18,0x12,0x0E,0x0E,0x0E,0x0E,0x0E,0x0E,0x0E,0x0E,0x0E,0x0E,0x0E,0x0E,0x0E,0x0E,0x0E,0x0E,0x0E,
0x39,0,51,0xE6,0x28,0x1A,0x14,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x28,0x1A,0x14,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,
0x39,0,2,0x9F,0x05,
0x39,0,7,0xB2,0x24,0x20,0x05,0x0F,0xFF,0xFF,
0x39,0,9,0xB3,0xA0,0x00,0x28,0x00,0x00,0x00,0x3F,0xFF,
0x39,0,13,0xB4,0x02,0x0E,0x3E,0x00,0x00,0x10,0x06,0x00,0x00,0x02,0x50,0x0F,
0x39,0,21,0xB5,0x0F,0xFF,0x07,0xFF,0x03,0x33,0x01,0x47,0x01,0x46,0x00,0xCD,0x00,0x66,0x00,0x3A,0x00,0x14,0x00,0x08,
0x39,0,21,0xB6,0x03,0xFF,0x01,0xFF,0x00,0x00,0x00,0x00,0x03,0xFF,0x01,0xFF,0x00,0x00,0x00,0x00,0x03,0xFF,0x01,0xFF,
0x39,0,9,0xB8,0x00,0x00,0x00,0x00,0x13,0x1F,0x30,0x6E,
0x39,0,41,0xE0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,41,0xE1,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,21,0xE2,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,41,0xE3,0x01,0xE1,0x01,0xE1,0x01,0xE1,0x01,0xE1,0x01,0xFF,0x01,0xFF,0x01,0xFF,0x01,0xFF,0x01,0xFF,0x01,0xFF,0x01,0xE1,0x01,0xE1,0x01,0xE1,0x01,0xE1,0x01,0xFF,0x01,0xFF,0x01,0xFF,0x01,0xFF,0x01,0xFF,0x01,0xFF,
0x39,0,41,0xE4,0x01,0xE1,0x01,0xE1,0x01,0xE1,0x01,0xE1,0x01,0xFF,0x01,0xFF,0x01,0xFF,0x01,0xFF,0x01,0xFF,0x01,0xFF,0x01,0xE1,0x01,0xE1,0x01,0xE1,0x01,0xE1,0x01,0xFF,0x01,0xFF,0x01,0xFF,0x01,0xFF,0x01,0xFF,0x01,0xFF,
0x39,0,21,0xE5,0x01,0xFF,0x01,0xFF,0x01,0xFF,0x01,0xFF,0x01,0xFF,0x01,0xFF,0x01,0xFF,0x01,0xFF,0x01,0xFF,0x01,0xFF,
#if 1 // renew
0x39,0,2,0x9F, 0x04,
0x39,0,19,0xB3, 0x00, 0x00, 0x10, 0x00, 0x30, 0x50, 0x00, 0x70, 0xB0, 0x00, 0xD0, 0xF0, 0x11, 0x30, 0x70, 0x12, 0xF0, 0x70,
0x39,0,21,0xB4, 0x23, 0xF0, 0x70, 0x34, 0xF0, 0xF0, 0x67, 0xF0, 0xF0, 0x8A, 0xF0, 0xF0, 0xCD, 0xF0, 0xF0, 0xEF, 0xF0, 0xF0, 0x0F, 0xFF,
0x39,0,2,0x9F, 0x05,
0x39,0,21,0xB5, 0x0F, 0xFF, 0x07, 0xFF, 0x03, 0x33, 0x01, 0x47, 0x01, 0x46, 0x00, 0xCD, 0x00, 0x66, 0x00, 0x3A, 0x00, 0x14, 0x00, 0x08,
0x39,0,21,0xB6, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x39,0,2,0x9F,0x05,
0x39,0,2,0xF9,0x80,
0x39,0,4,0xFF,0x00,0x00,0x01,
0x39,0,2,0x9F,0x06,
0x39,0,3,0xFF,0x00,0x01,
0x39,0,5,0xFE,0x01,0x00,0x00,0x00,
0x39,0,22,0xF1,0x02,0x00,0x45,0x23,0xC1,0x2C,0x33,0x94,0xF3,0x44,0x10,0x75,0x45,0xC7,0x0F,0x55,0x7C,0xEB,0x66,0x4A,0xA0,
0x39,0,18,0xF2,0x67,0xF7,0x7C,0x88,0x6B,0xD6,0x9A,0x3C,0x07,0xAB,0xC7,0x27,0xBB,0x84,0xE6,0xB0,0xE6,
0x39,0,22,0xF3,0x02,0x00,0x45,0x22,0xAC,0xDE,0x23,0xF3,0x98,0x34,0x99,0x20,0x44,0x62,0xA3,0x45,0xF3,0x5D,0x56,0xBA,0x0B,
0x39,0,18,0xF4,0x66,0x64,0xDA,0x78,0xBA,0x16,0x89,0x6F,0x1D,0x9A,0xBF,0x0A,0xAA,0x5D,0xAC,0xA0,0xAC,
0x39,0,22,0xF5,0x02,0x00,0xE9,0x33,0x81,0xDD,0x44,0x19,0xB4,0x45,0xD5,0x3C,0x55,0x98,0xE9,0x66,0x61,0xDD,0x77,0x43,0x9E,
0x39,0,18,0xF6,0x78,0xF9,0x8B,0x9A,0x8E,0x03,0xAB,0x74,0x49,0xCC,0x14,0x70,0xCD,0xDC,0x3E,0xD0,0x3E,
0x39,0,2,0xFF,0x01,
0x39,0,5,0xFE,0x01,0x01,0x00,0x00,
0x39,0,22,0xF1,0x00,0x00,0x01,0x12,0x7E,0x64,0x23,0xBD,0x8A,0x33,0xAD,0xED,0x44,0x64,0x90,0x55,0x23,0x81,0x56,0xD4,0x2C,
0x39,0,18,0xF2,0x66,0x71,0xF3,0x78,0xCA,0x27,0x89,0x7E,0x2B,0x9A,0xCB,0x1A,0xAA,0x66,0xB5,0xA0,0xB5,
0x39,0,22,0xF3,0x00,0x00,0x01,0x11,0x13,0xE8,0x23,0x5B,0x0A,0x33,0x20,0x62,0x34,0xEB,0x0B,0x44,0xA3,0xFC,0x55,0x45,0x9F,
0x39,0,18,0xF4,0x56,0xDE,0x5D,0x77,0x21,0x72,0x78,0xC5,0x5C,0x89,0xE5,0x2A,0x99,0x6D,0xB1,0x90,0xB1,
0x39,0,22,0xF5,0x02,0x00,0x08,0x23,0xFD,0x68,0x34,0x96,0x48,0x44,0x6A,0xA6,0x55,0x2A,0x5A,0x56,0xF8,0x64,0x67,0xBC,0x1A,
0x39,0,18,0xF6,0x77,0x66,0xF0,0x89,0xD8,0x3D,0x9A,0x9F,0x59,0xBB,0x00,0x58,0xBB,0xAC,0xFC,0xB0,0xFC,
0x39,0,2,0xFF,0x01,
0x39,0,5,0xFE,0x01,0x02,0x00,0x00,
0x39,0,22,0xF1,0x00,0x00,0x01,0x00,0x02,0x03,0x12,0x63,0xC2,0x33,0x0D,0x53,0x33,0xA6,0xF9,0x44,0x61,0xC0,0x55,0x14,0x5D,
0x39,0,18,0xF2,0x56,0x9C,0x03,0x67,0xBF,0x0F,0x77,0x58,0xDA,0x88,0x56,0x8F,0x89,0xC9,0x00,0x90,0x00,
0x39,0,22,0xF3,0x00,0x00,0x01,0x00,0x02,0x03,0x02,0x87,0x27,0x22,0x83,0xD1,0x33,0x1B,0x79,0x34,0xDE,0x3A,0x44,0x90,0xDB,
0x39,0,18,0xF4,0x55,0x14,0x74,0x66,0x29,0x76,0x67,0xBA,0x2D,0x77,0xA2,0xD3,0x88,0x08,0x38,0x80,0x38,
0x39,0,22,0xF5,0x02,0x00,0x61,0x22,0x62,0xC3,0x33,0x2A,0x99,0x34,0xDF,0x31,0x44,0x5F,0xBB,0x55,0x22,0x8A,0x56,0xEC,0x39,
0x39,0,18,0xF6,0x66,0x7D,0xED,0x78,0xB7,0x0D,0x88,0x5C,0xE9,0x99,0x70,0xB1,0x9A,0xED,0x2A,0xA0,0x2A,
0x39,0,2,0xFF,0x01,
0x39,0,5,0xFE,0x01,0x03,0x00,0x00,
0x39,0,22,0xF1,0x00,0x00,0x01,0x00,0x02,0x03,0x00,0x04,0x05,0x00,0x06,0xF0,0x23,0xCD,0x16,0x34,0xA6,0x11,0x44,0x5E,0xA3,
0x39,0,18,0xF2,0x45,0xDB,0x42,0x56,0xDB,0x21,0x66,0x66,0xD2,0x77,0x36,0x66,0x77,0x96,0xBE,0x70,0xBE,
0x39,0,22,0xF3,0x00,0x00,0x02,0x00,0x05,0x07,0x00,0x0C,0x0D,0x11,0x44,0x80,0x22,0x4C,0xA8,0x33,0x36,0x87,0x34,0xDA,0x29,
0x39,0,18,0xF4,0x44,0x57,0xBF,0x55,0x49,0x8D,0x56,0xD6,0x37,0x66,0x97,0xC3,0x67,0xF0,0x16,0x70,0x16,
0x39,0,22,0xF5,0x01,0x00,0x1F,0x11,0x20,0x21,0x33,0x13,0x14,0x33,0x3F,0x6E,0x34,0xAF,0x0E,0x44,0x8D,0xC9,0x55,0x21,0x73,
0x39,0,18,0xF6,0x56,0xA8,0x1B,0x67,0xC1,0x0B,0x77,0x56,0xCC,0x88,0x39,0x6C,0x88,0x9E,0xCC,0x80,0xCC,
0x39,0,2,0xFF,0x01,
0x39,0,5,0xFE,0x01,0x04,0x00,0x00,
0x39,0,22,0xF1,0x00,0x00,0x01,0x00,0x02,0x03,0x00,0x04,0x17,0x11,0x50,0xCF,0x33,0x76,0xC2,0x44,0x75,0xC3,0x55,0x19,0x5A,
0x39,0,18,0xF2,0x55,0x93,0xF4,0x66,0x8C,0xD0,0x77,0x0C,0x7A,0x78,0xDD,0x0A,0x88,0x3A,0x61,0x80,0x61,
0x39,0,22,0xF3,0x00,0x00,0x01,0x00,0x02,0x03,0x00,0x04,0x05,0x12,0x7B,0x46,0x33,0x11,0x65,0x34,0xFA,0x4D,0x44,0x97,0xDD,
0x39,0,18,0xF4,0x55,0x16,0x74,0x66,0x06,0x49,0x66,0x81,0xE9,0x77,0x45,0x73,0x77,0x97,0xBF,0x70,0xBF,
0x39,0,22,0xF5,0x02,0x00,0xEC,0x33,0x56,0x57,0x33,0x58,0xD9,0x34,0xFF,0x38,0x44,0x88,0xD6,0x55,0x39,0x97,0x56,0xD4,0x23,
0x39,0,18,0xF6,0x66,0x5C,0xC5,0x77,0x6B,0xB4,0x78,0xF2,0x68,0x89,0xD3,0x04,0x99,0x35,0x62,0x90,0x62,
0x39,0,2,0xFF,0x01,
0x39,0,5,0xFE,0x01,0x05,0x00,0x00,
0x39,0,22,0xF1,0x00,0x00,0x01,0x00,0x02,0x03,0x00,0x04,0x05,0x02,0x08,0x6F,0x23,0xB9,0xBF,0x44,0x2E,0xA1,0x45,0xF7,0x38,
0x39,0,18,0xF2,0x55,0x73,0xD7,0x66,0x78,0xB9,0x67,0xFB,0x64,0x77,0xC7,0xF5,0x88,0x20,0x51,0x80,0x51,
0x39,0,22,0xF3,0x00,0x00,0x01,0x00,0x02,0x03,0x00,0x04,0x05,0x01,0x06,0x32,0x23,0xAA,0x2B,0x34,0xB0,0x1B,0x44,0x69,0xAD,
0x39,0,18,0xF4,0x45,0xF5,0x51,0x56,0xF1,0x2E,0x66,0x70,0xCF,0x77,0x2C,0x5A,0x77,0x81,0xAA,0x70,0xAA,
0x39,0,22,0xF5,0x02,0x00,0xEC,0x33,0x86,0xB0,0x33,0xB1,0xB2,0x34,0xE8,0x0C,0x44,0x5F,0x9E,0x55,0x23,0x74,0x56,0xBC,0x01,
0x39,0,18,0xF6,0x66,0x50,0xB0,0x77,0x5D,0xA1,0x78,0xE5,0x57,0x88,0xC0,0xF1,0x99,0x1F,0x4F,0x90,0x4F,
0x39,0,2,0xFF,0x01,
0x39,0,5,0xFE,0x01,0x06,0x00,0x00,
0x39,0,22,0xF1,0x00,0x00,0x01,0x00,0x02,0x03,0x00,0x04,0x05,0x00,0x06,0x07,0x01,0x0F,0x18,0x34,0x90,0x21,0x45,0xAA,0x01,
0x39,0,18,0xF2,0x55,0x3A,0xA8,0x66,0x4D,0x8E,0x67,0xD7,0x3E,0x77,0xA5,0xD0,0x78,0xFB,0x2B,0x80,0x2B,
0x39,0,22,0xF3,0x00,0x00,0x01,0x00,0x02,0x03,0x00,0x04,0x05,0x00,0x06,0x07,0x01,0x26,0xEA,0x33,0x17,0xAD,0x44,0x16,0x70,
0x39,0,18,0xF4,0x45,0xAC,0x1B,0x55,0xBD,0xFB,0x66,0x45,0xA7,0x77,0x0F,0x33,0x77,0x5D,0x8B,0x70,0x8B,
0x39,0,22,0xF5,0x02,0x00,0xEC,0x33,0x86,0xB3,0x33,0xCC,0xCD,0x33,0xCE,0xCF,0x44,0x2E,0x76,0x45,0xE9,0x58,0x55,0x9F,0xE1,
0x39,0,18,0xF6,0x66,0x2A,0x97,0x77,0x41,0x82,0x78,0xC8,0x39,0x88,0xA6,0xD2,0x99,0x00,0x31,0x90,0x31,
0x39,0,2,0xFF,0x01,
0x39,0,5,0xFE,0x01,0x07,0x00,0x00,
0x39,0,22,0xF1,0x00,0x00,0x01,0x00,0x02,0x03,0x00,0x04,0x05,0x00,0x06,0x07,0x00,0x08,0xCB,0x13,0x06,0x59,0x44,0x62,0x95,
0x39,0,18,0xF2,0x45,0xEB,0x63,0x66,0x0B,0x57,0x67,0x93,0x08,0x77,0x6A,0x99,0x77,0xC0,0xEF,0x70,0xEF,
0x39,0,22,0xF3,0x00,0x00,0x01,0x00,0x02,0x03,0x00,0x04,0x05,0x00,0x06,0x07,0x00,0x08,0x09,0x12,0xC8,0xF3,0x34,0xB5,0x00,
0x39,0,18,0xF4,0x44,0x4E,0xC6,0x55,0x70,0xBD,0x56,0xF6,0x70,0x66,0xCF,0xFD,0x77,0x1F,0x52,0x70,0x52,
0x39,0,22,0xF5,0x02,0x00,0xEC,0x33,0x54,0x6E,0x33,0x6F,0x70,0x33,0x71,0x72,0x34,0xE6,0x2F,0x45,0xAE,0x0F,0x55,0x59,0xB7,
0x39,0,18,0xF6,0x56,0xEE,0x5B,0x77,0x0B,0x51,0x78,0x91,0x05,0x88,0x6C,0x9D,0x88,0xC7,0xF8,0x80,0xF8,
0x39,0,2,0xFF,0x01,
0x39,0,5,0xFE,0x01,0x08,0x00,0x00,
0x39,0,22,0xF1,0x00,0x00,0x01,0x00,0x02,0x03,0x00,0x04,0x05,0x00,0x06,0x07,0x00,0x08,0x09,0x00,0x0A,0x55,0x00,0x78,0x79,
0x39,0,18,0xF2,0x34,0x8C,0x68,0x55,0x49,0x98,0x56,0xD1,0x48,0x66,0xA9,0xD0,0x67,0xFB,0x27,0x70,0x27,
0x39,0,22,0xF3,0x00,0x00,0x01,0x00,0x02,0x03,0x00,0x04,0x05,0x00,0x06,0x07,0x00,0x08,0x09,0x01,0x0A,0x15,0x12,0xD1,0x2A,
0x39,0,18,0xF4,0x33,0x15,0xD4,0x44,0xAB,0xF0,0x55,0x26,0xA9,0x66,0x11,0x30,0x66,0x59,0x87,0x60,0x87,
0x39,0,22,0xF5,0x02,0x00,0x55,0x22,0x56,0x57,0x22,0xD1,0xFA,0x33,0x10,0x13,0x33,0x14,0x8C,0x44,0x01,0x68,0x45,0xB5,0x16,
0x39,0,18,0xF6,0x55,0x4B,0xB1,0x66,0x6B,0xAB,0x67,0xDE,0x5C,0x77,0xBB,0xDC,0x88,0x07,0x2D,0x80,0x2D,
0x39,0,2,0xFF,0x01,
0x39,0,5,0xFE,0x01,0x09,0x00,0x00,
0x39,0,22,0xF1,0x00,0x00,0x01,0x00,0x02,0x03,0x00,0x04,0x05,0x00,0x06,0x07,0x00,0x08,0x09,0x00,0x0A,0x0B,0x00,0x0C,0x0F,
0x39,0,18,0xF2,0x00,0x50,0x51,0x34,0xF5,0xB1,0x45,0xF1,0x82,0x56,0xDE,0x11,0x66,0x3D,0x5D,0x60,0x5D,
0x39,0,22,0xF3,0x00,0x00,0x01,0x00,0x02,0x03,0x00,0x04,0x05,0x00,0x06,0x07,0x00,0x08,0x09,0x00,0x0A,0x0B,0x00,0x0C,0x0D,
0x39,0,18,0xF4,0x02,0xA8,0x37,0x34,0x7F,0x08,0x44,0x5A,0xD4,0x55,0x38,0x60,0x55,0x9C,0xB8,0x50,0xB8,
0x39,0,22,0xF5,0x00,0x00,0x01,0x00,0x02,0x03,0x01,0xE2,0x25,0x12,0x49,0x76,0x22,0xF8,0xF9,0x33,0x3A,0xAE,0x44,0x1C,0x64,
0x39,0,18,0xF6,0x45,0x96,0x10,0x56,0xCA,0x0D,0x66,0x52,0xAB,0x77,0x0C,0x2B,0x77,0x64,0x88,0x70,0x88,
0x39,0,2,0xFF,0x01,
0x39,0,2,0x9F,0x05,
0x39,0,2,0xF9,0x00,
0x39,0,4,0xFF,0x00,0x00,0x00,
0x39,0,2,0x9F,0x06,
0x39,0,3,0xFF,0x00,0x00,
#else // GAMMA correct for reddish
0x39,0,2,0x9F, 0x04,
0x39,0,19,0xB3, 0x00, 0x00, 0x10, 0x00, 0x30, 0x50, 0x00, 0x70, 0xB0, 0x00, 0xD0, 0xF0, 0x11, 0x30, 0x70, 0x12, 0xF0, 0x70,
0x39,0,21,0xB4, 0x23, 0xF0, 0x70, 0x34, 0xF0, 0xF0, 0x67, 0xF0, 0xF0, 0x8A, 0xF0, 0xF0, 0xCD, 0xF0, 0xF0, 0xEF, 0xF0, 0xF0, 0x0F, 0xFF,
0x39,0,2,0x9F, 0x05,
0x39,0,21,0xB5, 0x0F, 0xFF, 0x07, 0xFF, 0x03, 0x33, 0x01, 0x47, 0x01, 0x46, 0x00, 0xCD, 0x00, 0x66, 0x00, 0x3A, 0x00, 0x14, 0x00, 0x08,
0x39,0,21,0xB6, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
0x39,0,2,0x9F, 0x05,
0x39,0,2,0xF9, 0x80,
0x39,0,4,0xFF, 0x00, 0x00, 0x01,
0x39,0,2,0x9F, 0x06,
0x39,0,3,0xFF, 0x00, 0x01,
0x39,0,5,0xFE, 0x01, 0x00, 0x00, 0x00,
0x39,0,22,0xF1, 0x02, 0x00, 0x4C, 0x23, 0xB9, 0x2D, 0x34, 0x8F, 0x26, 0x44, 0x5E, 0x94, 0x45, 0xEF, 0x3F, 0x56, 0xC3, 0x31, 0x66, 0x91, 0xE4,
0x39,0,18,0xF2, 0x77, 0x32, 0xBF, 0x89, 0xA9, 0x12, 0x9A, 0x74, 0x35, 0xAB, 0xF2, 0x4E, 0xBC, 0xAD, 0x0C, 0xC0, 0x0C,
0x39,0,22,0xF3, 0x02, 0x00, 0x59, 0x22, 0x9E, 0xE9, 0x33, 0x31, 0xAE, 0x34, 0xE6, 0x15, 0x44, 0x68, 0xB3, 0x55, 0x2D, 0x93, 0x56, 0xEC, 0x3C,
0x39,0,18,0xF4, 0x67, 0x84, 0x07, 0x78, 0xDB, 0x39, 0x89, 0x8F, 0x2F, 0x9A, 0xCA, 0x16, 0xAA, 0x61, 0xAC, 0xA0, 0xAC,
0x39,0,22,0xF5, 0x03, 0x00, 0x11, 0x33, 0x82, 0xF0, 0x44, 0x4F, 0xE9, 0x55, 0x28, 0x5F, 0x56, 0xC3, 0x1C, 0x67, 0xAC, 0x22, 0x77, 0x86, 0xE1,
0x39,0,18,0xF6, 0x88, 0x33, 0xC9, 0x9A, 0xC4, 0x38, 0xAB, 0xAA, 0x75, 0xCC, 0x36, 0x95, 0xCD, 0xF9, 0x5D, 0xD0, 0x5D,
0x39,0,2,0xFF, 0x01,
0x39,0,5,0xFE, 0x01, 0x01, 0x00, 0x00,
0x39,0,22,0xF1, 0x00, 0x00, 0xC0, 0x22, 0x02, 0xAD, 0x33, 0x1E, 0xBD, 0x34, 0xF9, 0x2D, 0x44, 0x86, 0xD2, 0x55, 0x4C, 0xB2, 0x66, 0x0B, 0x5C,
0x39,0,18,0xF2, 0x67, 0xA4, 0x23, 0x78, 0xF8, 0x58, 0x89, 0xAC, 0x4D, 0x9A, 0xE5, 0x34, 0xAA, 0x7D, 0xC8, 0xA0, 0xC8,
0x39,0,22,0xF3, 0x00, 0x00, 0x56, 0x12, 0x80, 0x22, 0x23, 0x91, 0x2D, 0x33, 0x6B, 0x9F, 0x34, 0xF6, 0x3F, 0x45, 0xB7, 0x19, 0x55, 0x6C, 0xB7,
0x39,0,18,0xF4, 0x56, 0xFB, 0x73, 0x77, 0x37, 0x8D, 0x78, 0xDB, 0x69, 0x89, 0xED, 0x2C, 0x99, 0x67, 0xA2, 0x90, 0xA2,
0x39,0,22,0xF5, 0x02, 0x00, 0x89, 0x33, 0x0E, 0x83, 0x34, 0xE3, 0x7B, 0x44, 0xB7, 0xED, 0x55, 0x4C, 0x9E, 0x66, 0x25, 0x96, 0x67, 0xF5, 0x4B,
0x39,0,18,0xF6, 0x78, 0x98, 0x1F, 0x99, 0x01, 0x65, 0x9A, 0xC1, 0x74, 0xBB, 0x1D, 0x6E, 0xBC, 0xBB, 0x0D, 0xC0, 0x0D,
0x39,0,2,0xFF, 0x01,
0x39,0,5,0xFE, 0x01, 0x02, 0x00, 0x00,
0x39,0,22,0xF1, 0x00, 0x00, 0x01, 0x01, 0x02, 0x58, 0x23, 0x3C, 0x00, 0x33, 0x42, 0x77, 0x34, 0xD0, 0x17, 0x44, 0x89, 0xE7, 0x55, 0x33, 0x79,
0x39,0,18,0xF2, 0x56, 0xB8, 0x26, 0x67, 0xDA, 0x27, 0x77, 0x71, 0xF1, 0x88, 0x63, 0x9C, 0x89, 0xD1, 0x04, 0x90, 0x04,
0x39,0,22,0xF3, 0x00, 0x00, 0x01, 0x00, 0x02, 0xA0, 0x12, 0x9D, 0x6B, 0x22, 0xAB, 0xE2, 0x33, 0x3C, 0x86, 0x34, 0xF9, 0x52, 0x44, 0x9F, 0xE1,
0x39,0,18,0xF4, 0x55, 0x1C, 0x82, 0x66, 0x2C, 0x75, 0x67, 0xB8, 0x2E, 0x77, 0x98, 0xCB, 0x78, 0xFA, 0x27, 0x80, 0x27,
0x39,0,22,0xF5, 0x01, 0x00, 0xF9, 0x22, 0x7F, 0xEC, 0x33, 0x46, 0xCE, 0x44, 0x08, 0x37, 0x44, 0x8E, 0xD6, 0x55, 0x4F, 0xB4, 0x66, 0x08, 0x54,
0x39,0,18,0xF6, 0x67, 0x99, 0x0E, 0x78, 0xCE, 0x21, 0x88, 0x6C, 0xF7, 0x99, 0x72, 0xAE, 0x9A, 0xE7, 0x27, 0xA0, 0x27,
0x39,0,2,0xFF, 0x01,
0x39,0,5,0xFE, 0x01, 0x03, 0x00, 0x00,
0x39,0,22,0xF1, 0x00, 0x00, 0x01, 0x00, 0x02, 0x03, 0x01, 0x04, 0x60, 0x22, 0x1F, 0x83, 0x23, 0xFF, 0x56, 0x34, 0xCD, 0x29, 0x44, 0x72, 0xB1,
0x39,0,18,0xF2, 0x45, 0xE8, 0x4A, 0x56, 0xE6, 0x29, 0x66, 0x68, 0xD4, 0x77, 0x35, 0x61, 0x77, 0x8E, 0xB6, 0x70, 0xB6,
0x39,0,22,0xF3, 0x00, 0x00, 0x01, 0x00, 0x02, 0x03, 0x01, 0x04, 0x1E, 0x12, 0xAC, 0x01, 0x22, 0x75, 0xC6, 0x33, 0x3E, 0x98, 0x34, 0xE1, 0x21,
0x39,0,18,0xF4, 0x44, 0x56, 0xB3, 0x55, 0x47, 0x86, 0x56, 0xC1, 0x26, 0x66, 0x82, 0xAB, 0x66, 0xD3, 0xF9, 0x60, 0xF9,
0x39,0,22,0xF5, 0x02, 0x00, 0x48, 0x22, 0x49, 0x4A, 0x23, 0xAD, 0x2C, 0x33, 0x61, 0x90, 0x34, 0xDF, 0x24, 0x44, 0x91, 0xEB, 0x55, 0x36, 0x7A,
0x39,0,18,0xF6, 0x56, 0xB7, 0x20, 0x67, 0xCA, 0x12, 0x77, 0x54, 0xC7, 0x88, 0x30, 0x5E, 0x88, 0x8B, 0xBA, 0x80, 0xBA,
0x39,0,2,0xFF, 0x01,
0x39,0,5,0xFE, 0x01, 0x04, 0x00, 0x00,
0x39,0,22,0xF1, 0x00, 0x00, 0x01, 0x00, 0x02, 0x03, 0x01, 0x04, 0xFC, 0x23, 0xDF, 0x46, 0x34, 0xC5, 0x17, 0x44, 0x8F, 0xE4, 0x55, 0x2C, 0x69,
0x39,0,18,0xF2, 0x55, 0xA0, 0xFF, 0x66, 0x97, 0xD7, 0x77, 0x14, 0x7D, 0x78, 0xDA, 0x08, 0x88, 0x31, 0x59, 0x80, 0x59,
0x39,0,22,0xF3, 0x00, 0x00, 0x01, 0x00, 0x02, 0x03, 0x01, 0x04, 0xE2, 0x22, 0x76, 0xCF, 0x33, 0x3E, 0x90, 0x44, 0x04, 0x5D, 0x44, 0xA2, 0xDE,
0x39,0,18,0xF4, 0x55, 0x12, 0x6C, 0x56, 0xFF, 0x3C, 0x66, 0x75, 0xD9, 0x77, 0x31, 0x58, 0x77, 0x7D, 0xA3, 0x70, 0xA3,
0x39,0,22,0xF5, 0x03, 0x00, 0x0D, 0x33, 0x0E, 0x0F, 0x33, 0x69, 0xF1, 0x44, 0x24, 0x52, 0x44, 0x9E, 0xDF, 0x55, 0x4B, 0xA1, 0x56, 0xED, 0x2E,
0x39,0,18,0xF6, 0x66, 0x6A, 0xD0, 0x77, 0x72, 0xB6, 0x78, 0xF7, 0x65, 0x88, 0xCB, 0xF9, 0x99, 0x23, 0x4D, 0x90, 0x4D,
0x39,0,2,0xFF, 0x01,
0x39,0,5,0xFE, 0x01, 0x05, 0x00, 0x00,
0x39,0,22,0xF1, 0x00, 0x00, 0x01, 0x00, 0x02, 0x03, 0x00, 0x04, 0x05, 0x02, 0x6F, 0x81, 0x33, 0x64, 0xD1, 0x44, 0x5E, 0xBE, 0x55, 0x0A, 0x4B,
0x39,0,18,0xF2, 0x55, 0x82, 0xE3, 0x66, 0x80, 0xC3, 0x67, 0xFF, 0x6A, 0x77, 0xC6, 0xF1, 0x88, 0x19, 0x42, 0x80, 0x42,
0x39,0,22,0xF3, 0x00, 0x00, 0x01, 0x00, 0x02, 0x03, 0x00, 0x04, 0x05, 0x12, 0x70, 0x2A, 0x23, 0xDE, 0x45, 0x34, 0xCD, 0x2D, 0x44, 0x79, 0xB9,
0x39,0,18,0xF4, 0x45, 0xF0, 0x4D, 0x56, 0xE5, 0x25, 0x66, 0x5F, 0xC2, 0x77, 0x1B, 0x42, 0x77, 0x69, 0x8E, 0x70, 0x8E,
0x39,0,22,0xF5, 0x03, 0x00, 0x13, 0x33, 0x32, 0x33, 0x33, 0x34, 0xC7, 0x34, 0xFE, 0x2E, 0x44, 0x80, 0xC3, 0x55, 0x30, 0x8A, 0x56, 0xD7, 0x1B,
0x39,0,18,0xF6, 0x66, 0x56, 0xBC, 0x77, 0x60, 0xA6, 0x78, 0xE4, 0x52, 0x88, 0xB5, 0xE3, 0x99, 0x0E, 0x38, 0x90, 0x38,
0x39,0,2,0xFF, 0x01,
0x39,0,5,0xFE, 0x01, 0x06, 0x00, 0x00,
0x39,0,22,0xF1, 0x00, 0x00, 0x01, 0x00, 0x02, 0x03, 0x00, 0x04, 0x05, 0x00, 0x06, 0x07, 0x13, 0x79, 0x0C, 0x34, 0xF3, 0x70, 0x45, 0xCB, 0x0F,
0x39,0,18,0xF2, 0x55, 0x4D, 0xB5, 0x66, 0x58, 0x9D, 0x67, 0xDA, 0x46, 0x77, 0xA5, 0xD2, 0x78, 0xF9, 0x21, 0x80, 0x21,
0x39,0,22,0xF3, 0x00, 0x00, 0x01, 0x00, 0x02, 0x03, 0x00, 0x04, 0x05, 0x00, 0x06, 0x07, 0x12, 0xAA, 0x86, 0x33, 0x58, 0xD1, 0x44, 0x29, 0x71,
0x39,0,18,0xF4, 0x45, 0xAF, 0x16, 0x55, 0xB9, 0xFB, 0x66, 0x38, 0xA0, 0x67, 0xF9, 0x22, 0x77, 0x47, 0x6D, 0x70, 0x6D,
0x39,0,22,0xF5, 0x02, 0x00, 0x4D, 0x22, 0x4E, 0x4F, 0x33, 0xB7, 0xB8, 0x33, 0xB9, 0xF1, 0x44, 0x49, 0x92, 0x55, 0x05, 0x63, 0x55, 0xB4, 0xFA,
0x39,0,18,0xF6, 0x66, 0x38, 0xA0, 0x77, 0x44, 0x8B, 0x78, 0xC9, 0x38, 0x88, 0x9A, 0xC9, 0x89, 0xF2, 0x1B, 0x90, 0x1B,
0x39,0,2,0xFF, 0x01,
0x39,0,5,0xFE, 0x01, 0x07, 0x00, 0x00,
0x39,0,22,0xF1, 0x00, 0x00, 0x01, 0x00, 0x02, 0x03, 0x00, 0x04, 0x05, 0x00, 0x06, 0x07, 0x00, 0x08, 0x0E, 0x33, 0x37, 0xFB, 0x44, 0x6B, 0xBD,
0x39,0,18,0xF2, 0x55, 0x00, 0x6E, 0x66, 0x19, 0x5F, 0x67, 0x9E, 0x0A, 0x77, 0x68, 0x90, 0x77, 0xBB, 0xE1, 0x70, 0xE1,
0x39,0,22,0xF3, 0x00, 0x00, 0x01, 0x00, 0x02, 0x03, 0x00, 0x04, 0x05, 0x00, 0x06, 0x07, 0x01, 0x08, 0x11, 0x23, 0xA3, 0x52, 0x34, 0xBE, 0x13,
0x39,0,18,0xF4, 0x44, 0x56, 0xC6, 0x55, 0x71, 0xB8, 0x56, 0xF8, 0x61, 0x66, 0xBC, 0xE4, 0x77, 0x0B, 0x2E, 0x70, 0x2E,
0x39,0,22,0xF5, 0x02, 0x00, 0x6C, 0x22, 0x6D, 0x6E, 0x23, 0x6F, 0xAE, 0x33, 0xAF, 0xB0, 0x44, 0x03, 0x4E, 0x45, 0xC6, 0x26, 0x55, 0x79, 0xC3,
0x39,0,18,0xF6, 0x66, 0x02, 0x6D, 0x77, 0x12, 0x57, 0x78, 0x95, 0x02, 0x88, 0x62, 0x8F, 0x88, 0xB7, 0xDF, 0x80, 0xDF,
0x39,0,2,0xFF, 0x01,
0x39,0,5,0xFE, 0x01, 0x08, 0x00, 0x00,
0x39,0,22,0xF1, 0x00, 0x00, 0x01, 0x00, 0x02, 0x03, 0x00, 0x04, 0x05, 0x00, 0x06, 0x07, 0x00, 0x08, 0x09, 0x00, 0x0A, 0x0B, 0x23, 0xAE, 0x8C,
0x39,0,18,0xF2, 0x44, 0x01, 0x95, 0x55, 0x4C, 0x93, 0x56, 0xD5, 0x43, 0x66, 0x9F, 0xC8, 0x67, 0xEF, 0x12, 0x70, 0x12,
0x39,0,22,0xF3, 0x00, 0x00, 0x01, 0x00, 0x02, 0x03, 0x00, 0x04, 0x05, 0x00, 0x06, 0x07, 0x00, 0x08, 0x09, 0x01, 0x0A, 0x22, 0x22, 0x3E, 0xDE,
0x39,0,18,0xF4, 0x33, 0x4A, 0xDD, 0x44, 0x97, 0xDD, 0x55, 0x1E, 0x92, 0x56, 0xF0, 0x1A, 0x66, 0x41, 0x65, 0x60, 0x65,
0x39,0,22,0xF5, 0x00, 0x00, 0xF4, 0x00, 0xF5, 0xF6, 0x02, 0xF7, 0xC8, 0x22, 0xC9, 0xCA, 0x33, 0x41, 0x93, 0x44, 0x18, 0x79, 0x45, 0xCC, 0x0F,
0x39,0,18,0xF6, 0x55, 0x4F, 0xBE, 0x66, 0x66, 0xA8, 0x67, 0xE4, 0x49, 0x77, 0xA2, 0xCB, 0x78, 0xF2, 0x17, 0x80, 0x17,
0x39,0,2,0xFF, 0x01,
0x39,0,5,0xFE, 0x01, 0x09, 0x00, 0x00,
0x39,0,22,0xF1, 0x00, 0x00, 0x01, 0x00, 0x02, 0x03, 0x00, 0x04, 0x05, 0x00, 0x06, 0x07, 0x00, 0x08, 0x09, 0x00, 0x0A, 0x0B, 0x00, 0x0C, 0x0D,
0x39,0,18,0xF2, 0x03, 0x59, 0x2C, 0x44, 0x69, 0xBE, 0x55, 0x03, 0x72, 0x56, 0xD6, 0x00, 0x66, 0x27, 0x4A, 0x60, 0x4A,
0x39,0,22,0xF3, 0x00, 0x00, 0x01, 0x00, 0x02, 0x03, 0x00, 0x04, 0x05, 0x00, 0x06, 0x07, 0x00, 0x08, 0x09, 0x00, 0x0A, 0x0B, 0x00, 0x0C, 0x0D,
0x39,0,18,0xF4, 0x12, 0x4C, 0x8A, 0x33, 0xA6, 0xFC, 0x44, 0x42, 0xB3, 0x55, 0x11, 0x3C, 0x55, 0x67, 0x91, 0x50, 0x91,
0x39,0,22,0xF5, 0x00, 0x00, 0x01, 0x00, 0x02, 0x03, 0x02, 0x04, 0x02, 0x22, 0x03, 0x04, 0x22, 0x71, 0xD8, 0x33, 0x5F, 0xC5, 0x44, 0x18, 0x62,
0x39,0,18,0xF6, 0x45, 0x9F, 0x06, 0x55, 0xB3, 0xF7, 0x66, 0x36, 0x9D, 0x67, 0xF4, 0x18, 0x77, 0x3C, 0x5E, 0x70, 0x5E,
0x39,0,2,0xFF, 0x01,
0x39,0,2,0x9F, 0x05,
0x39,0,2,0xF9, 0x00,
0x39,0,4,0xFF, 0x00, 0x00, 0x00,
0x39,0,2,0x9F, 0x06,
0x39,0,3,0xFF, 0x00, 0x00,
#endif
0x39,0,2,0x9F,0x07,
//0x39,0,8,0xB2,0x10,0x10,0x10,0x10,0x04,0x00,0x98,
0x39,0,8,0xB2,0x04,0x04,0x04,0x04,0x04,0x00,0x98,
0x39,0,8,0xB3,0x15,0x15,0x15,0x15,0x04,0x00,0x9A,
0x39,0,8,0xB4,0x20,0x20,0x20,0x20,0x04,0x00,0x96,
0x39,0,8,0xB6,0x04,0x04,0x04,0x04,0x04,0x02,0x60,
0x39,0,8,0xB7,0x04,0x04,0x04,0x04,0x04,0x02,0x60,
0x39,0,33,0xB9,0x01,0x02,0x03,0x04,0x05,0x06,0x07,0x08,0x09,0x0A,0x0B,0x0C,0x0D,0x0E,0x0F,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,33,0xBA,0x01,0x02,0x03,0x04,0x05,0x06,0x07,0x08,0x09,0x0A,0x0B,0x0C,0x0D,0x0E,0x0F,0x10,0x11,0x12,0x13,0x14,0x15,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,33,0xBB,0x01,0x02,0x03,0x04,0x05,0x06,0x07,0x08,0x09,0x0A,0x0B,0x0C,0x0D,0x0E,0x0F,0x10,0x11,0x12,0x13,0x14,0x15,0x16,0x17,0x18,0x19,0x1A,0x1B,0x1C,0x1D,0x1E,0x1F,0x20,
0x39,0,33,0xBD,0x01,0x02,0x03,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,33,0xBE,0x01,0x02,0x03,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,31,0xC0,0x00,0x7A,0x7A,0x00,0x7A,0x7A,0x00,0x6A,0x46,0x00,0x26,0x1A,0x00,0x0F,0x0B,0x00,0x0B,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,31,0xC1,0x00,0x9A,0x9A,0x00,0x9A,0x9A,0x00,0x6A,0x46,0x00,0x26,0x1A,0x00,0x0F,0x0B,0x00,0x0B,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,31,0xC2,0x00,0x96,0x96,0x00,0x96,0x96,0x00,0x6A,0x46,0x00,0x26,0x1B,0x00,0x0F,0x0B,0x00,0x0B,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,7,0xC4,0x10,0x30,0x1C,0x00,0x1C,0x1C,
0x39,0,7,0xC5,0x22,0x60,0x60,0x22,0x60,0x60,
0x39,0,41,0xD6,0x0F,0xFF,0x07,0xFF,0x03,0x33,0x01,0x47,0x01,0x46,0x00,0xCD,0x00,0x66,0x00,0x3A,0x00,0x14,0x00,0x08,0x00,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,21,0xD7,0x03,0xFF,0x01,0xFF,0x00,0x00,0x00,0x00,0x03,0xFF,0x01,0xFF,0x00,0x00,0x00,0x00,0x03,0xFF,0x01,0xFF,
0x39,0,2,0x9F,0x0C,
0x39,0,9,0xB4,0xF0,0xC0,0xC0,0x1B,0x1B,0x00,0x00,0x16,
0x39,0,2,0x9F,0x08,
0x39,0,4,0xB2,0x10,0x00,0x02,
0x39,0,2,0xB4,0x11,
0x39,0,8,0xB5,0x00,0x02,0x01,0xFF,0x20,0x40,0xC0,
0x39,0,3,0xB6,0x58,0x03,
0x39,0,55,0xB7,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,
0x39,0,55,0xB8,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,
0x39,0,55,0xB9,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,
0x39,0,55,0xBA,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,
0x39,0,55,0xBB,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,
0x39,0,55,0xBC,0x44,0x2C,0x22,0x44,0x18,0x0E,0x43,0x00,0xF4,0x33,0xE6,0xD8,0x34,0xD3,0x2C,0x44,0x22,0x18,0x44,0x0E,0x00,0x33,0xF4,0xE6,0x33,0xD8,0xD3,0x44,0x2C,0x22,0x44,0x18,0x0E,0x43,0x00,0xF4,0x33,0xE6,0xD8,0x34,0xD3,0x2C,0x44,0x22,0x18,0x44,0x0E,0x00,0x33,0xF4,0xE6,0x33,0xD8,0xD3,
0x39,0,55,0xBD,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,
0x39,0,55,0xBE,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,
0x39,0,55,0xBF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,
0x39,0,55,0xC0,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,
0x39,0,55,0xC1,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,
0x39,0,55,0xC2,0x44,0x2C,0x22,0x44,0x18,0x0E,0x43,0x00,0xF4,0x33,0xE6,0xD8,0x34,0xD3,0x2C,0x44,0x22,0x18,0x44,0x0E,0x00,0x33,0xF4,0xE6,0x33,0xD8,0xD3,0x44,0x2C,0x22,0x44,0x18,0x0E,0x43,0x00,0xF4,0x33,0xE6,0xD8,0x34,0xD3,0x2C,0x44,0x22,0x18,0x44,0x0E,0x00,0x33,0xF4,0xE6,0x33,0xD8,0xD3,
0x39,0,55,0xC3,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,
0x39,0,55,0xC4,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,
0x39,0,55,0xC5,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,
0x39,0,55,0xC6,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,
0x39,0,55,0xC7,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,
0x39,0,55,0xC8,0x44,0x2C,0x22,0x44,0x18,0x0E,0x43,0x00,0xF4,0x33,0xE6,0xD8,0x34,0xD3,0x2C,0x44,0x22,0x18,0x44,0x0E,0x00,0x33,0xF4,0xE6,0x33,0xD8,0xD3,0x44,0x2C,0x22,0x44,0x18,0x0E,0x43,0x00,0xF4,0x33,0xE6,0xD8,0x34,0xD3,0x2C,0x44,0x22,0x18,0x44,0x0E,0x00,0x33,0xF4,0xE6,0x33,0xD8,0xD3,
0x39,0,10,0xC9,0x16,0x33,0x3D,0x01,0x00,0x0F,0xFF,0x00,0x00,
0x39,0,2,0xCA,0xF0,
0x39,0,6,0xCB,0x00,0x01,0x7C,0x42,0x00,
0x39,0,5,0xCC,0x00,0x01,0x00,0x1F,
0x39,0,4,0xCD,0x00,0x01,0x00,
0x39,0,33,0xCE,0x00,0x25,0x00,0xA9,0x01,0x9C,0x03,0x08,0x04,0xF4,0x07,0x65,0x0A,0x62,0x0D,0xEE,0x12,0x0C,0x16,0xC1,0x1C,0x10,0x21,0xFC,0x28,0x87,0x2F,0xB5,0x37,0x86,0x3F,0xFF,
0x39,0,12,0xCF,0xFC,0x01,0xFF,0xFF,0xFF,0xFF,0xFF,0xBA,0x4E,0xED,0x00,
0x39,0,53,0xD0,0x00,0x00,0x01,0xF1,0xEC,0x23,0xE4,0xDC,0x45,0xD7,0xDE,0x67,0xCB,0xC2,0x89,0xC0,0xC4,0xAB,0xC2,0xBC,0xCD,0xB5,0xAB,0xEF,0xAA,0xB4,0x00,0x00,0x01,0xFA,0xF1,0x23,0xEB,0xE4,0x45,0xE3,0xEB,0x67,0xDB,0xD1,0x89,0xCE,0xD0,0xAB,0xCC,0xC8,0xCD,0xC1,0xBA,0xEF,0xB9,0xB8,
0x39,0,53,0xD1,0x00,0x00,0x01,0xFF,0xF0,0x23,0xE8,0xE3,0x45,0xE1,0xE5,0x67,0xD7,0xCC,0x89,0xCE,0xD5,0xAB,0xCE,0xCA,0xCD,0xC4,0xBD,0xEF,0xB9,0xB7,0x00,0x00,0x01,0xF1,0xEB,0x23,0xE1,0xDD,0x45,0xD0,0xD0,0x67,0xBF,0xB1,0x89,0x9D,0x8A,0xAB,0x78,0x62,0xCD,0x49,0x30,0xEF,0x14,0x06,
0x39,0,53,0xD2,0x00,0x00,0x01,0xF5,0xEE,0x23,0xE8,0xE1,0x45,0xD6,0xD4,0x67,0xBF,0xB6,0x89,0xA6,0x99,0xAB,0x88,0x75,0xCD,0x60,0x47,0xEF,0x29,0x05,0x00,0x00,0x01,0xF4,0xEF,0x23,0xE7,0xE1,0x45,0xD7,0xD4,0x67,0xC2,0xB6,0x89,0xA4,0x91,0xAB,0x7A,0x63,0xCD,0x51,0x3B,0xEF,0x1E,0x01,
0x39,0,53,0xD3,0x00,0x00,0x01,0xFF,0xEC,0x23,0xE3,0xD9,0x45,0xD1,0xD6,0x67,0xC1,0xB7,0x89,0xB4,0xBE,0xAB,0xB3,0xAB,0xCD,0xA4,0x9A,0xEF,0x99,0xA1,0x00,0x00,0x11,0x0B,0xFC,0x23,0xF5,0xE4,0x45,0xDF,0xE4,0x67,0xCD,0xC5,0x89,0xBF,0xCD,0xAB,0xB7,0xB4,0xCD,0xAA,0xA4,0xEF,0xA6,0xA5,
0x39,0,53,0xD4,0x00,0x00,0x11,0x02,0xF2,0x23,0xE9,0xE0,0x45,0xDC,0xDD,0x67,0xCC,0xC2,0x89,0xC4,0xD0,0xAB,0xBF,0xB9,0xCD,0xB3,0xAC,0xEF,0xA8,0xA5,0x00,0x00,0x12,0x16,0x20,0x34,0x28,0x30,0x56,0x31,0x38,0x78,0x2F,0x29,0x9A,0x19,0x10,0xAB,0xFF,0xED,0xCD,0xD6,0xBC,0xEF,0xAF,0xB2,
0x39,0,53,0xD5,0x00,0x00,0x12,0x33,0x36,0x34,0x3F,0x45,0x56,0x49,0x4E,0x78,0x47,0x48,0x9A,0x3F,0x3C,0xBC,0x30,0x29,0xDD,0x15,0xFE,0xEF,0xDE,0xBE,0x00,0x00,0x12,0x18,0x26,0x34,0x31,0x39,0x56,0x3D,0x42,0x78,0x3B,0x38,0x9A,0x2D,0x22,0xBC,0x0E,0x0A,0xCD,0xF8,0xE0,0xEF,0xC9,0xB9,
0x39,0,53,0xD6,0x80,0x00,0x02,0xD9,0x08,0x34,0x13,0x1A,0x46,0xE9,0x3C,0x78,0x76,0x8C,0x9A,0xA4,0xBE,0xBC,0xCE,0xD8,0xDE,0xD7,0xD7,0xF1,0xF4,0x16,0x80,0x00,0x02,0xCF,0x01,0x34,0x0A,0x1A,0x46,0xEE,0x44,0x78,0x7B,0x90,0x9A,0xAC,0xC7,0xBC,0xD5,0xD8,0xDE,0xE3,0xED,0xF0,0xF4,0xFC,
0x39,0,27,0xD7,0x80,0x00,0x02,0xF1,0x1B,0x34,0x27,0x2A,0x46,0xFF,0x5D,0x78,0x94,0xAD,0x9A,0xC7,0xDC,0xBC,0xE9,0xE9,0xDE,0xE7,0xE4,0xF1,0xF4,0x06,
0x39,0,18,0xD8,0x80,0x96,0x91,0x8D,0x8B,0x8A,0x96,0x90,0x8E,0x87,0x90,0x96,0x92,0x85,0x8F,0x94,0x96,
0x39,0,2,0x9F,0x09,
0x39,0,3,0xB2,0x9C,0x09,
0x39,0,9,0xB3,0x00,0x00,0x00,0x00,0x80,0x80,0x80,0x80,
0x39,0,16,0xB4,0x76,0xFF,0xDD,0x43,0x84,0x48,0x32,0x47,0x22,0x11,0x85,0x0D,0x00,0xAC,0x01,
0x39,0,35,0xC0,0x00,0x00,0x01,0x64,0x9C,0xC8,0x18,0x55,0x52,0x72,0x9A,0xB8,0x5A,0xE0,0xF4,0x26,0x58,0x00,0x00,0x01,0x64,0x9C,0xC8,0x18,0x55,0x52,0x72,0x9A,0xB8,0x5A,0xE0,0xF4,0x26,0x58,
0x39,0,29,0xC1,0xFF,0xF5,0xED,0xE5,0xDD,0xD6,0xD0,0xD0,0xCD,0x0F,0xC5,0xC3,0xC3,0xC3,0x00,0x0F,0x13,0x16,0x1A,0x20,0x23,0x25,0x2D,0x00,0x2D,0x2D,0x2D,0x2D,
0x39,0,29,0xC2,0xFF,0xF5,0xED,0xE5,0xDD,0xD6,0xD3,0xCD,0xC9,0x0F,0xC9,0xC0,0xC0,0xC0,0x00,0x0F,0x15,0x15,0x1B,0x20,0x2F,0x35,0x35,0x00,0x38,0x38,0x38,0x38,
0x39,0,29,0xC3,0xFF,0xF5,0xED,0xE5,0xDE,0xD6,0xD3,0xCD,0xC9,0x0F,0xC9,0xC0,0xC0,0xC0,0x00,0x0F,0x13,0x15,0x1B,0x20,0x2F,0x35,0x35,0x00,0x38,0x38,0x38,0x38,
0x39,0,29,0xC4,0xFF,0xF5,0xED,0xE5,0xDE,0xD6,0xD3,0xCD,0xC9,0x0F,0xC9,0xC0,0xC0,0xC0,0x00,0x0F,0x13,0x15,0x1B,0x20,0x2F,0x35,0x35,0x00,0x38,0x38,0x38,0x38,
0x39,0,29,0xC5,0xFF,0xF5,0xED,0xE5,0xDD,0xD6,0xD3,0xCD,0xC9,0x0F,0xC9,0xC0,0xC0,0xC0,0x00,0x0F,0x15,0x15,0x1B,0x20,0x2F,0x35,0x35,0x00,0x38,0x38,0x38,0x38,
0x39,0,29,0xC6,0xFF,0xF5,0xED,0xE8,0xE0,0xD6,0xD3,0xCD,0xC9,0x0F,0xC9,0xC0,0xC0,0xC0,0x00,0x0F,0x15,0x15,0x1B,0x20,0x2F,0x35,0x35,0x00,0x38,0x38,0x38,0x38,
0x39,0,29,0xC7,0xFF,0xF5,0xED,0xE8,0xE0,0xD6,0xD3,0xCD,0xC9,0x0F,0xC9,0xC0,0xC0,0xC0,0x00,0x0F,0x15,0x15,0x1B,0x20,0x2F,0x35,0x35,0x00,0x38,0x38,0x38,0x38,
0x39,0,29,0xC8,0xFF,0xF5,0xED,0xE8,0xE0,0xD6,0xD3,0xCD,0xC9,0x0F,0xC9,0xC0,0xC0,0xC0,0x00,0x0F,0x15,0x15,0x1B,0x20,0x2F,0x35,0x35,0x00,0x38,0x38,0x38,0x38,
0x39,0,29,0xC9,0xFF,0xF5,0xED,0xE8,0xE0,0xD6,0xD3,0xCD,0xC9,0x0F,0xC9,0xC0,0xC0,0xC0,0x00,0x0F,0x15,0x15,0x1B,0x20,0x2F,0x35,0x35,0x00,0x38,0x38,0x38,0x38,
0x39,0,29,0xCA,0xFF,0xF5,0xED,0xE5,0xDD,0xD6,0xD3,0xCD,0xC9,0x0F,0xC9,0xC0,0xC0,0xC0,0x00,0x0F,0x15,0x15,0x1B,0x20,0x2F,0x35,0x35,0x00,0x38,0x38,0x38,0x38,
0x39,0,29,0xCB,0xFF,0xF3,0xF0,0xE8,0xDD,0xD8,0xD5,0xD0,0xCD,0x0F,0xC5,0xC3,0xC3,0xC3,0x00,0x08,0x15,0x18,0x1F,0x20,0x23,0x25,0x2D,0x00,0x2D,0x2D,0x2D,0x2D,
0x39,0,29,0xCC,0xFF,0xF3,0xF0,0xE8,0xDD,0xD8,0xD5,0xD0,0xCD,0x0F,0xC5,0xC3,0xC3,0xC3,0x00,0x08,0x0F,0x12,0x1F,0x20,0x23,0x25,0x2D,0x00,0x2D,0x2D,0x2D,0x2D,
0x39,0,29,0xCD,0xFF,0xF3,0xF0,0xE8,0xDD,0xD8,0xD5,0xD0,0xCD,0x0F,0xC5,0xC3,0xC3,0xC3,0x00,0x08,0x17,0x18,0x1F,0x20,0x23,0x25,0x2D,0x00,0x2D,0x2D,0x2D,0x2D,
0x39,0,29,0xCE,0xFF,0xF3,0xF0,0xE8,0xDD,0xD8,0xD5,0xD0,0xCD,0x0F,0xC5,0xC3,0xC3,0xC3,0x00,0x08,0x17,0x18,0x1F,0x20,0x23,0x25,0x2D,0x00,0x2D,0x2D,0x2D,0x2D,
0x39,0,29,0xCF,0xFF,0xF5,0xF3,0xED,0xDE,0xD8,0xCD,0xC8,0xCF,0x0F,0xCD,0xC5,0xC3,0xC3,0x00,0x08,0x0D,0x0F,0x12,0x15,0x17,0x18,0x1D,0x00,0x1F,0x20,0x25,0x2D,
0x39,0,29,0xD1,0xFF,0xF5,0xF3,0xED,0xDE,0xD8,0xCD,0xC8,0xCF,0x0F,0xCD,0xC5,0xC3,0xC3,0x00,0x08,0x0D,0x0F,0x12,0x15,0x17,0x18,0x1D,0x00,0x1F,0x20,0x25,0x2D,
0x39,0,29,0xD2,0xFF,0xF5,0xF3,0xED,0xDE,0xD8,0xCD,0xC8,0xCF,0x0F,0xCD,0xC5,0xC3,0xC3,0x00,0x08,0x0D,0x0F,0x12,0x15,0x17,0x18,0x1D,0x00,0x1F,0x20,0x25,0x2D,
0x39,0,29,0xD3,0xFF,0xF5,0xF3,0xED,0xDE,0xD8,0xCD,0xC8,0xCF,0x0F,0xCD,0xC5,0xC3,0xC3,0x00,0x08,0x0D,0x0F,0x12,0x15,0x17,0x18,0x1D,0x00,0x1F,0x20,0x25,0x2D,
0x39,0,29,0xD4,0xFF,0xF5,0xF3,0xED,0xDE,0xD8,0xCD,0xC8,0xCF,0x0F,0xCD,0xC5,0xC3,0xC3,0x00,0x0F,0x12,0x0F,0x12,0x15,0x17,0x18,0x1D,0x00,0x1F,0x20,0x25,0x2D,
0x39,0,17,0xD5,0x17,0xF9,0xFE,0xFD,0x05,0x00,0x00,0x00,0x17,0xF9,0xF8,0xFE,0x00,0x00,0x00,0x00,
0x39,0,17,0xD6,0x18,0xF5,0xF8,0x03,0x00,0x00,0x00,0x00,0x17,0xEB,0xED,0xEF,0x00,0x00,0x00,0x00,
0x39,0,13,0xD7,0x05,0x00,0x80,0x00,0x80,0xAF,0x00,0x80,0x00,0x80,0x03,0xFF,
0x39,0,17,0xD8,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
0x39,0,6,0xEE,0x30,0x10,0x00,0x10,0xFF,
0x39,0,2,0x9F,0x0A,
0x39,0,12,0xB2,0x1F,0x00,0x10,0x01,0x00,0x07,0x00,0x00,0x00,0x11,0x00,
0x39,0,43,0xB3,0x10,0x10,0x00,0x10,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x10,0x00,0x10,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x3F,0x00,0x00,0x00,0x00,0x00,0x00,0x3F,0x00,0x00,
0x39,0,43,0xB4,0x00,0x00,0x00,0x00,0x3F,0x00,0x00,0x00,0x00,0x00,0x00,0x3F,0x00,0x00,0x00,0x00,0x00,0x00,0x3F,0x00,0x00,0x00,0x00,0x00,0x00,0x3F,0x00,0x00,0x00,0x00,0x00,0x00,0x3F,0x00,0x00,0x00,0x00,0x00,0x00,0x3F,0x00,0x00,
0x39,0,43,0xB5,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x10,0x00,0x10,0x10,0x00,0x00,0x10,0x10,0x00,0x10,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3F,0x00,0x00,0x00,0x00,0x00,0x00,0x3F,0x00,0x00,
0x39,0,12,0xBE,0x00,0x1F,0xFF,0x13,0x91,0x0F,0x04,0x00,0x24,0x80,0xFF,
0x39,0,2,0x9F,0x0B,  //Middle circle setting REG 0xBE
0x39,0,10,0xB2,0x01,0x3F,0x3F,0x0F,0x3F,0x0F,0x5F,0x0F,0x0F,
0x39,0,49,0xB9,0x32,0x00,0x00,0x00,0x00,0x00,0x6B,0x54,0x24,0x1C,0xB0,0x14,0xC8,0x5C,0x24,0x1C,0xB0,0xFF,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xFF,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xFF,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,49,0xBA,0x32,0x00,0x00,0x00,0x00,0x00,0x54,0x69,0x24,0x1C,0xB0,0x14,0xC8,0x5C,0x24,0x1C,0xB0,0xFF,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xFF,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xFF,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,49,0xBC,0x32,0x00,0x00,0x00,0x00,0x00,0x4b,0x4b,0x24,0x1C,0xB0,0x14,0xD1,0x65,0x24,0x1C,0xB0,0xFF,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xFF,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xFF,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,49,0xBE,0x32,0x00,0x00,0x00,0x00,0x00,0x25,0x25,0x20,0x1C,0x33,0x00,0x00,0x00,0x00,0x25,0x25,0xFF,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xFF,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xFF,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,20,0xC6,0x8F,0x04,0x04,0x04,0x04,0xFF,0xFF,0xFF,0xFF,0x00,0x22,0x22,0x22,0x22,0x00,0x1E,0x1E,0x1E,0x1E,
0x39,0,20,0xC7,0x0F,0x04,0x04,0x04,0x04,0xFF,0xFF,0xFF,0xFF,0x00,0x22,0x22,0x22,0x22,0x00,0x1E,0x1E,0x1E,0x1E,
0x39,0,16,0xC8,0xF9,0x05,0x05,0xB0,0xE0,0xB0,0x50,0xBA,0xF0,0xB0,0xE0,0xB0,0x20,0xD0,0x50,
0x39,0,2,0x9F,0x0D,
0x39,0,16,0xB2,0x25,0x10,0x21,0x01,0x02,0x10,0x00,0x00,0x16,0x10,0x00,0x00,0x01,0xAA,0x90,
0x39,0,2,0xB3,0xB0,
0x39,0,13,0xB5,0x00,0x24,0x07,0x01,0x00,0x00,0x00,0x00,0x20,0x04,0xEE,0x21,
0x39,0,4,0xB6,0x02,0x12,0x22,
0x39,0,5,0xB7,0x20,0xF0,0xC0,0xE0,
0x39,0,13,0xB8,0x20,0xF0,0xC0,0xE0,0x20,0xF0,0xC0,0xE0,0x20,0xF0,0xC0,0xE0,
0x39,0,5,0xB9,0x01,0x01,0x01,0x01,
0x39,0,3,0xBA,0x00,0x00,
0x39,0,2,0xBB,0x01,
0x39,0,21,0xBC,0x0F,0xFF,0x07,0xFF,0x03,0x33,0x01,0x47,0x01,0x46,0x00,0xCD,0x00,0x66,0x00,0x3A,0x00,0x14,0x00,0x08,
0x39,0,6,0xBD,0x02,0x00,0x02,0x06,0x5B,
0x39,0,12,0xC7,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x2A,0x00,
0x39,0,2,0x48,0x03,  //0x03：120hz  0x23:60hz
0x39,0,1,0x11,
0x39,0,3,0x51,0x00,0x0F,
0x39,0,2,0x53,0xE0,
0x39,0,1,0x35,
//0x39,0,1,0x29,
#endif
#if 0 //AMOLED_ICNA3508_gamma_correct --old version
0x39,0,3,0x9C,0xA5,0xA5,
0x39,0,3,0xFD,0x5A,0x5A,
0x39,0,2,0x9F,0x0F,
0x39,0,2,0xB3,0x00,
0x39,0,2,0xD7,0x11,
0x39,0,2,0x9F,0x01,
0x39,0,4,0xB2,0x5A,0x04,0xAF,
0x39,0,36,0xB3,0x00,0xBA,0x00,0x14,0x0C,0x22,0x00,0xBA,0x30,0x14,0x2C,0x00,0x00,0xBA,0x90,0x14,0x4C,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xBA,0x00,0x14,0x0C,0x44,0x1C,0x1C,0x1C,0x1C,0x1C,
0x39,0,19,0xCD,0x06,0x1F,0x1F,0x06,0x00,0x09,0x00,0x96,0x1F,0x03,0x28,0x00,0x96,0x1F,0x09,0x46,0x00,0x96,
0x39,0,2,0xD0,0x01,
0x39,0,3,0xE2,0x46,0x20,
0x39,0,3,0xEA,0x04,0x0B,
0x39,0,9,0xEE,0x40,0x38,0x28,0x28,0x28,0x28,0x28,0xC2,//add for ICNA5608
0x39,0,2,0x9F,0x02,
0x39,0,26,0xB2,0x00,0xC9,0x32,0x10,0x11,0x12,0x12,0x00,0x08,0x78,0x21,0x11,0x14,0x13,0x11,0x11,0x11,0x11,0x11,0x11,0x11,0x21,0x21,0x11,0x1A,
0x39,0,14,0xB4,0x00,0x00,0x8C,0x00,0x00,0x00,0x00,0x00,0x25,0x25,0x25,0x25,0x25,
0x39,0,7,0xB5,0x00,0x30,0x30,0x30,0x30,0x2A,
0x39,0,20,0xB6,0x05,0x00,0x00,0x11,0x11,0x11,0x1C,0x08,0x1C,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,
//0x39,0,17,0xB7,0x00,0x00,0x00,0x00,0x00,0x15,0x00,0x06,0x06,0x03,0x06,0x06,0x03,0x06,0x06,0x03,
0x39,0,17,0xB7,0x05,0x00,0x15,0x00,0x00,0x15,0x70,0x03,0x03,0x03,0x03,0x03,0x03,0x03,0x03,0x03, //ver2.0
0x39,0,14,0xB8,0x00,0x00,0x00,0x73,0x28,0x73,0x28,0x73,0x28,0x73,0x28,0x73,0x28,
0x39,0,9,0xB9,0x00,0x00,0x50,0x00,0x00,0x0F,0x0F,0x00,
0x39,0,14,0xBA,0x0E,0xFF,0xFF,0xFF,0x00,0x54,0x00,0x44,0x04,0x44,0x04,0x04,0x00,
0x39,0,26,0xBB,0x00,0x5A,0x91,0x91,0x5A,0x00,0x5A,0x91,0x91,0x5A,0x00,0x5A,0x91,0x91,0x5A,0x00,0x5A,0x91,0x91,0x5A,0x00,0x3C,0x78,0x78,0x3C,
0x39,0,5,0xBE,0x5B,0x17,0x04,0x5B,
0x39,0,17,0xBF,0x0C,0x8F,0xFF,0x10,0x00,0x07,0x00,0x0A,0x01,0x20,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,17,0xC1,0x05,0x21,0x22,0x1D,0x1F,0x1E,0x20,0x01,0x30,0x31,0x32,0x33,0x3D,0x3D,0x3D,0x3D,
0x39,0,17,0xC2,0x05,0x21,0x22,0x1D,0x1F,0x1E,0x20,0x01,0x30,0x31,0x32,0x33,0x3D,0x3D,0x3D,0x3D,
0x39,0,10,0xC3,0x11,0x60,0x00,0x40,0x00,0x40,0x00,0x00,0x00,
0x39,0,26,0xC4,0x00,0x0C,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x00,0x1F,0x1F,0x00,0x00,0x0D,0x00,0x00,0x00,0x00,
0x39,0,17,0xD2,0x00,0x00,0x13,0x00,0x00,0x13,0x00,0x00,0x17,0x00,0x00,0x17,0x00,0x00,0x17,0x00,
0x39,0,14,0xC7,0x00,0x04,0x04,0x04,0x04,0x00,0x04,0x04,0x04,0x04,0x00,0x04,0x04,
0x39,0,14,0xC8,0x00,0xB1,0xB1,0xB1,0xB1,0x00,0xB1,0xB1,0xB1,0xB1,0x00,0xB1,0xB1,
0x39,0,27,0xC6,0x00,0x00,0x0f,0x00,0x00,0x11,0x00,0x00,0x00,0x90,0x00,0x00,0x00,0x00,0x08,0x00,0x02,0x00,0x00,0x00,0x00,0x00,0x55,0x01,0x01,0x00,
0x39,0,27,0xCB,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x90,0x92,0x90,0x92,0x00,0x90,0x92,0x90,0x92,0x00,0x90,0x92,
0x39,0,27,0xCC,0x00,0x76,0xff,0x76,0xff,0x00,0x76,0xff,0x76,0xff,0x00,0x76,0xff,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
//0x39,0,19,0xD7,0x49,0xC3,0x20,0x7A,0x44,0x00,0x04,0x04,0x00,0xF9,0xF9,0xF4,0xAB,0xA9,0xAE,0xF0,0x00,0x00,
//0x39,0,19,0xD7,0x4D,0xC3,0x20,0x7A,0x53,0x00,0x66,0x02,0x00,0xCC,0xF7,0xF4,0xCC,0xA9,0xAE,0xF0,0x00,0x00,  //功耗高
0x39,0,19,0xD7,0x4D,0xC3,0x20,0x7A,0x53,0x00,0x66,0x02,0x00,0xCC,0xF7,0xF4,0xCC,0xA9,0xAE,0xF0,0x00,0x00, 
0x39,0,41,0xD8,0x00,0x04,0x76,0x22,0xFF,0x00,0x04,0x76,0x22,0xFF,0x00,0x04,0x76,0x22,0xFF,0x00,0x04,0x76,0x22,0xFF,0x00,0x04,0x76,0x22,0xFF,0x90,0x76,0xFF,0x90,0x76,0xFF,0x90,0x76,0xFF,0x90,0x76,0xFF,0x90,0x76,0xFF,
0x39,0,12,0xD9,0x10,0x40,0x10,0x00,0x10,0x00,0x10,0x00,0x10,0x00,0x10,
0x39,0,4,0xE0,0x00,0x00,0x60,
0x39,0,6,0xE1,0x43,0x00,0x11,0x60,0x0D,
0x39,0,51,0xE2,0x15,0x00,0x39,0x42,0x24,0x15,0x00,0x39,0x42,0x24,0x15,0x00,0x39,0x42,0x24,0x15,0x00,0x39,0x42,0x24,0x15,0x00,0x39,0x42,0x24,0x15,0x00,0x39,0x42,0x24,0x15,0x00,0x39,0x42,0x24,0x15,0x00,0x39,0x42,0x24,0x15,0x00,0x39,0x42,0x24,0x15,0x00,0x39,0x42,0x24,
0x39,0,4,0xED,0x00,0x01,0x80,
0x39,0,18,0xEE,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x30,0x88,0x88,0x29,0x00,0x00,0x00,0x00,
0x39,0,6,0xEF,0x00,0x85,0x88,0x87,0x87,
0x39,0,2,0x9F,0x03,
0x39,0,33,0xB2,0x11,0x00,0x00,0x89,0x30,0x80,0x09,0x60,0x04,0x38,0x00,0x0C,0x02,0x1C,0x02,0x1C,0x02,0x00,0x02,0x0E,0x00,0x20,0x01,0x1F,0x00,0x07,0x00,0x0C,0x08,0xBB,0x08,0x7A,
0x39,0,33,0xB3,0x18,0x00,0x10,0xF0,0x03,0x0C,0x20,0x00,0x06,0x0B,0x0B,0x33,0x0E,0x1C,0x2A,0x38,0x46,0x54,0x62,0x69,0x70,0x77,0x79,0x7B,0x7D,0x7E,0x01,0x02,0x01,0x00,0x09,0x40,
0x39,0,25,0xB4,0x09,0xBE,0x19,0xFC,0x19,0xFA,0x19,0xF8,0x1A,0x38,0x1A,0x78,0x1A,0xB6,0x2A,0xF6,0x2B,0x34,0x2B,0x74,0x3B,0x74,0x6B,0xF4,
0x39,0,2,0xC0,0x11,
0x39,0,2,0xC1,0x82,
0x39,0,3,0xC2,0x00,0xC0,
0x39,0,6,0xC6,0x11,0x00,0x00,0x01,0x01,
0x39,0,2,0xE2,0x01,
0x39,0,2,0x9F,0x04,
0x39,0,4,0xB2,0x01,0x80,0x00,
0x39,0,19,0xB3,0x00,0x00,0x10,0x00,0x30,0x50,0x00,0x70,0xB0,0x00,0xD0,0xF0,0x11,0x30,0x70,0x12,0xF0,0x70,
0x39,0,21,0xB4,0x23,0xF0,0x70,0x34,0xF0,0xF0,0x67,0xF0,0xF0,0x8A,0xF0,0xF0,0xCD,0xF0,0xF0,0xEF,0xF0,0xF0,0x0F,0xFF,
0x39,0,8,0xB6,0x01,0x20,0x00,0x0F,0xF0,0x10,0x06,
//0x39,0,3,0xB9,0x91,0xC1,
0x39,0,3,0xB9,0x90,0xC1,
0x39,0,3,0xBA,0x01,0x00,
0x39,0,10,0xBB,0x00,0x00,0x08,0x00,0x00,0x00,0xF2,0x00,0x00,
0x39,0,41,0xC1,0x0F,0xFF,0x07,0xFF,0x03,0x33,0x01,0x47,0x01,0x46,0x00,0xCD,0x00,0x66,0x00,0x3A,0x00,0x14,0x00,0x08,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,21,0xC2,0x03,0xFF,0x01,0xFF,0x00,0x00,0x00,0x00,0x03,0xFF,0x01,0xFF,0x00,0x00,0x00,0x00,0x03,0xFF,0x01,0xFF,
0x39,0,4,0xC3,0x00,0x08,0xB8,
0x39,0,20,0xC5,0x00,0x20,0x88,0x41,0xCF,0x4F,0x4F,0x00,0x48,0x53,0x29,0x21,0x28,0x2A,0x05,0x2F,0x00,0x20,0x0F,
0x39,0,37,0xC6,0x4B,0x00,0x90,0x00,0x02,0xD5,0x00,0x02,0xCB,0x01,0x10,0x43,0x00,0x0A,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,5,0xC8,0x48,0x48,0x53,0x53,
0x39,0,3,0xC9,0x88,0x88,
0x39,0,41,0xCC,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,
0x39,0,51,0xCD,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,
0x39,0,41,0xCE,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,
0x39,0,51,0xCF,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,
0x39,0,41,0xD0,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,
0x39,0,51,0xD1,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,
0x39,0,41,0xD2,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,
0x39,0,51,0xD3,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,0x19,
0x39,0,41,0xD4,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,
0x39,0,51,0xD5,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,
0x39,0,41,0xD6,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,
0x39,0,51,0xD7,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,
0x39,0,41,0xD8,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,
0x39,0,51,0xD9,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,
0x39,0,41,0xDD,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,
0x39,0,51,0xDE,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,
0x39,0,41,0xDF,0x23,0x15,0x0F,0x0B,0x0B,0x0B,0x0B,0x0B,0x0B,0x0B,0x0B,0x0B,0x0B,0x0B,0x0B,0x0B,0x0B,0x0B,0x0B,0x0B,0x26,0x18,0x12,0x0E,0x0E,0x0E,0x0E,0x0E,0x0E,0x0E,0x0E,0x0E,0x0E,0x0E,0x0E,0x0E,0x0E,0x0E,0x0E,0x0E,
0x39,0,51,0xE0,0x28,0x1A,0x14,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x28,0x1A,0x14,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,
0x39,0,41,0xE1,0x23,0x15,0x0F,0x0B,0x0B,0x0B,0x0B,0x0B,0x0B,0x0B,0x0B,0x0B,0x0B,0x0B,0x0B,0x0B,0x0B,0x0B,0x0B,0x0B,0x26,0x18,0x12,0x0E,0x0E,0x0E,0x0E,0x0E,0x0E,0x0E,0x0E,0x0E,0x0E,0x0E,0x0E,0x0E,0x0E,0x0E,0x0E,0x0E,
0x39,0,51,0xE2,0x28,0x1A,0x14,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x28,0x1A,0x14,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,
0x39,0,41,0xE3,0x23,0x15,0x0F,0x0B,0x0B,0x0B,0x0B,0x0B,0x0B,0x0B,0x0B,0x0B,0x0B,0x0B,0x0B,0x0B,0x0B,0x0B,0x0B,0x0B,0x26,0x18,0x12,0x0E,0x0E,0x0E,0x0E,0x0E,0x0E,0x0E,0x0E,0x0E,0x0E,0x0E,0x0E,0x0E,0x0E,0x0E,0x0E,0x0E,
0x39,0,51,0xE4,0x28,0x1A,0x14,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x28,0x1A,0x14,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,
0x39,0,41,0xE5,0x23,0x15,0x0F,0x0B,0x0B,0x0B,0x0B,0x0B,0x0B,0x0B,0x0B,0x0B,0x0B,0x0B,0x0B,0x0B,0x0B,0x0B,0x0B,0x0B,0x26,0x18,0x12,0x0E,0x0E,0x0E,0x0E,0x0E,0x0E,0x0E,0x0E,0x0E,0x0E,0x0E,0x0E,0x0E,0x0E,0x0E,0x0E,0x0E,
0x39,0,51,0xE6,0x28,0x1A,0x14,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x28,0x1A,0x14,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,0x21,
0x39,0,2,0x9F,0x05,
0x39,0,7,0xB2,0x24,0x20,0x05,0x0F,0xFF,0xFF,
0x39,0,9,0xB3,0xA0,0x00,0x28,0x00,0x00,0x00,0x3F,0xFF,
0x39,0,13,0xB4,0x02,0x0E,0x3E,0x00,0x00,0x10,0x06,0x00,0x00,0x02,0x50,0x0F,
0x39,0,21,0xB5,0x0F,0xFF,0x07,0xFF,0x03,0x33,0x01,0x47,0x01,0x46,0x00,0xCD,0x00,0x66,0x00,0x3A,0x00,0x14,0x00,0x08,
0x39,0,21,0xB6,0x03,0xFF,0x01,0xFF,0x00,0x00,0x00,0x00,0x03,0xFF,0x01,0xFF,0x00,0x00,0x00,0x00,0x03,0xFF,0x01,0xFF,
0x39,0,9,0xB8,0x00,0x00,0x00,0x00,0x13,0x1F,0x30,0x6E,
0x39,0,41,0xE0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,41,0xE1,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,21,0xE2,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,41,0xE3,0x01,0xE1,0x01,0xE1,0x01,0xE1,0x01,0xE1,0x01,0xFF,0x01,0xFF,0x01,0xFF,0x01,0xFF,0x01,0xFF,0x01,0xFF,0x01,0xE1,0x01,0xE1,0x01,0xE1,0x01,0xE1,0x01,0xFF,0x01,0xFF,0x01,0xFF,0x01,0xFF,0x01,0xFF,0x01,0xFF,
0x39,0,41,0xE4,0x01,0xE1,0x01,0xE1,0x01,0xE1,0x01,0xE1,0x01,0xFF,0x01,0xFF,0x01,0xFF,0x01,0xFF,0x01,0xFF,0x01,0xFF,0x01,0xE1,0x01,0xE1,0x01,0xE1,0x01,0xE1,0x01,0xFF,0x01,0xFF,0x01,0xFF,0x01,0xFF,0x01,0xFF,0x01,0xFF,
0x39,0,21,0xE5,0x01,0xFF,0x01,0xFF,0x01,0xFF,0x01,0xFF,0x01,0xFF,0x01,0xFF,0x01,0xFF,0x01,0xFF,0x01,0xFF,0x01,0xFF,
0x39,0,2,0x9F,0x04,
0x39,0,19,0xB3,0x00,0x00,0x10,0x00,0x30,0x50,0x00,0x70,0xB0,0x00,0xD0,0xF0,0x11,0x30,0x70,0x12,0xF0,0x70,
0x39,0,21,0xB4,0x23,0xF0,0x70,0x34,0xF0,0xF0,0x67,0xF0,0xF0,0x8A,0xF0,0xF0,0xCD,0xF0,0xF0,0xEF,0xF0,0xF0,0x0F,0xFF,
0x39,0,2,0x9F,0x05,
0x39,0,21,0xB5,0x0F,0xFF,0x07,0xFF,0x03,0x33,0x01,0x47,0x01,0x46,0x00,0xCD,0x00,0x66,0x00,0x3A,0x00,0x14,0x00,0x08,
0x39,0,21,0xB6,0x03,0xFF,0x01,0xFF,0x00,0x00,0x00,0x00,0x03,0xFF,0x01,0xFF,0x00,0x00,0x00,0x00,0x03,0xFF,0x01,0xFF,
0x39,0,2,0x9F,0x05,
0x39,0,2,0xF9,0x80,
0x39,0,4,0xFF,0x00,0x00,0x01,
0x39,0,2,0x9F,0x06,
0x39,0,3,0xFF,0x00,0x01,
0x39,0,5,0xFE,0x01,0x00,0x00,0x00,
0x39,0,22,0xF1,0x02,0x00,0x45,0x23,0xC1,0x2C,0x33,0x94,0xF3,0x44,0x10,0x75,0x45,0xC7,0x0F,0x55,0x7C,0xEB,0x66,0x4A,0xA0,
0x39,0,18,0xF2,0x67,0xF7,0x7C,0x88,0x6B,0xD6,0x9A,0x3C,0x07,0xAB,0xC7,0x27,0xBB,0x84,0xE6,0xB0,0xE6,
0x39,0,22,0xF3,0x02,0x00,0x45,0x22,0xAC,0xDE,0x23,0xF3,0x98,0x34,0x99,0x20,0x44,0x62,0xA3,0x45,0xF3,0x5D,0x56,0xBA,0x0B,
0x39,0,18,0xF4,0x66,0x64,0xDA,0x78,0xBA,0x16,0x89,0x6F,0x1D,0x9A,0xBF,0x0A,0xAA,0x5D,0xAC,0xA0,0xAC,
0x39,0,22,0xF5,0x02,0x00,0xE9,0x33,0x81,0xDD,0x44,0x19,0xB4,0x45,0xD5,0x3C,0x55,0x98,0xE9,0x66,0x61,0xDD,0x77,0x43,0x9E,
0x39,0,18,0xF6,0x78,0xF9,0x8B,0x9A,0x8E,0x03,0xAB,0x74,0x49,0xCC,0x14,0x70,0xCD,0xDC,0x3E,0xD0,0x3E,
0x39,0,2,0xFF,0x01,
0x39,0,5,0xFE,0x01,0x01,0x00,0x00,
0x39,0,22,0xF1,0x00,0x00,0x01,0x12,0x7E,0x64,0x23,0xBD,0x8A,0x33,0xAD,0xED,0x44,0x64,0x90,0x55,0x23,0x81,0x56,0xD4,0x2C,
0x39,0,18,0xF2,0x66,0x71,0xF3,0x78,0xCA,0x27,0x89,0x7E,0x2B,0x9A,0xCB,0x1A,0xAA,0x66,0xB5,0xA0,0xB5,
0x39,0,22,0xF3,0x00,0x00,0x01,0x11,0x13,0xE8,0x23,0x5B,0x0A,0x33,0x20,0x62,0x34,0xEB,0x0B,0x44,0xA3,0xFC,0x55,0x45,0x9F,
0x39,0,18,0xF4,0x56,0xDE,0x5D,0x77,0x21,0x72,0x78,0xC5,0x5C,0x89,0xE5,0x2A,0x99,0x6D,0xB1,0x90,0xB1,
0x39,0,22,0xF5,0x02,0x00,0x08,0x23,0xFD,0x68,0x34,0x96,0x48,0x44,0x6A,0xA6,0x55,0x2A,0x5A,0x56,0xF8,0x64,0x67,0xBC,0x1A,
0x39,0,18,0xF6,0x77,0x66,0xF0,0x89,0xD8,0x3D,0x9A,0x9F,0x59,0xBB,0x00,0x58,0xBB,0xAC,0xFC,0xB0,0xFC,
0x39,0,2,0xFF,0x01,
0x39,0,5,0xFE,0x01,0x02,0x00,0x00,
0x39,0,22,0xF1,0x00,0x00,0x01,0x00,0x02,0x03,0x12,0x63,0xC2,0x33,0x0D,0x53,0x33,0xA6,0xF9,0x44,0x61,0xC0,0x55,0x14,0x5D,
0x39,0,18,0xF2,0x56,0x9C,0x03,0x67,0xBF,0x0F,0x77,0x58,0xDA,0x88,0x56,0x8F,0x89,0xC9,0x00,0x90,0x00,
0x39,0,22,0xF3,0x00,0x00,0x01,0x00,0x02,0x03,0x02,0x87,0x27,0x22,0x83,0xD1,0x33,0x1B,0x79,0x34,0xDE,0x3A,0x44,0x90,0xDB,
0x39,0,18,0xF4,0x55,0x14,0x74,0x66,0x29,0x76,0x67,0xBA,0x2D,0x77,0xA2,0xD3,0x88,0x08,0x38,0x80,0x38,
0x39,0,22,0xF5,0x02,0x00,0x61,0x22,0x62,0xC3,0x33,0x2A,0x99,0x34,0xDF,0x31,0x44,0x5F,0xBB,0x55,0x22,0x8A,0x56,0xEC,0x39,
0x39,0,18,0xF6,0x66,0x7D,0xED,0x78,0xB7,0x0D,0x88,0x5C,0xE9,0x99,0x70,0xB1,0x9A,0xED,0x2A,0xA0,0x2A,
0x39,0,2,0xFF,0x01,
0x39,0,5,0xFE,0x01,0x03,0x00,0x00,
0x39,0,22,0xF1,0x00,0x00,0x01,0x00,0x02,0x03,0x00,0x04,0x05,0x00,0x06,0xF0,0x23,0xCD,0x16,0x34,0xA6,0x11,0x44,0x5E,0xA3,
0x39,0,18,0xF2,0x45,0xDB,0x42,0x56,0xDB,0x21,0x66,0x66,0xD2,0x77,0x36,0x66,0x77,0x96,0xBE,0x70,0xBE,
0x39,0,22,0xF3,0x00,0x00,0x02,0x00,0x05,0x07,0x00,0x0C,0x0D,0x11,0x44,0x80,0x22,0x4C,0xA8,0x33,0x36,0x87,0x34,0xDA,0x29,
0x39,0,18,0xF4,0x44,0x57,0xBF,0x55,0x49,0x8D,0x56,0xD6,0x37,0x66,0x97,0xC3,0x67,0xF0,0x16,0x70,0x16,
0x39,0,22,0xF5,0x01,0x00,0x1F,0x11,0x20,0x21,0x33,0x13,0x14,0x33,0x3F,0x6E,0x34,0xAF,0x0E,0x44,0x8D,0xC9,0x55,0x21,0x73,
0x39,0,18,0xF6,0x56,0xA8,0x1B,0x67,0xC1,0x0B,0x77,0x56,0xCC,0x88,0x39,0x6C,0x88,0x9E,0xCC,0x80,0xCC,
0x39,0,2,0xFF,0x01,
0x39,0,5,0xFE,0x01,0x04,0x00,0x00,
0x39,0,22,0xF1,0x00,0x00,0x01,0x00,0x02,0x03,0x00,0x04,0x17,0x11,0x50,0xCF,0x33,0x76,0xC2,0x44,0x75,0xC3,0x55,0x19,0x5A,
0x39,0,18,0xF2,0x55,0x93,0xF4,0x66,0x8C,0xD0,0x77,0x0C,0x7A,0x78,0xDD,0x0A,0x88,0x3A,0x61,0x80,0x61,
0x39,0,22,0xF3,0x00,0x00,0x01,0x00,0x02,0x03,0x00,0x04,0x05,0x12,0x7B,0x46,0x33,0x11,0x65,0x34,0xFA,0x4D,0x44,0x97,0xDD,
0x39,0,18,0xF4,0x55,0x16,0x74,0x66,0x06,0x49,0x66,0x81,0xE9,0x77,0x45,0x73,0x77,0x97,0xBF,0x70,0xBF,
0x39,0,22,0xF5,0x02,0x00,0xEC,0x33,0x56,0x57,0x33,0x58,0xD9,0x34,0xFF,0x38,0x44,0x88,0xD6,0x55,0x39,0x97,0x56,0xD4,0x23,
0x39,0,18,0xF6,0x66,0x5C,0xC5,0x77,0x6B,0xB4,0x78,0xF2,0x68,0x89,0xD3,0x04,0x99,0x35,0x62,0x90,0x62,
0x39,0,2,0xFF,0x01,
0x39,0,5,0xFE,0x01,0x05,0x00,0x00,
0x39,0,22,0xF1,0x00,0x00,0x01,0x00,0x02,0x03,0x00,0x04,0x05,0x02,0x08,0x6F,0x23,0xB9,0xBF,0x44,0x2E,0xA1,0x45,0xF7,0x38,
0x39,0,18,0xF2,0x55,0x73,0xD7,0x66,0x78,0xB9,0x67,0xFB,0x64,0x77,0xC7,0xF5,0x88,0x20,0x51,0x80,0x51,
0x39,0,22,0xF3,0x00,0x00,0x01,0x00,0x02,0x03,0x00,0x04,0x05,0x01,0x06,0x32,0x23,0xAA,0x2B,0x34,0xB0,0x1B,0x44,0x69,0xAD,
0x39,0,18,0xF4,0x45,0xF5,0x51,0x56,0xF1,0x2E,0x66,0x70,0xCF,0x77,0x2C,0x5A,0x77,0x81,0xAA,0x70,0xAA,
0x39,0,22,0xF5,0x02,0x00,0xEC,0x33,0x86,0xB0,0x33,0xB1,0xB2,0x34,0xE8,0x0C,0x44,0x5F,0x9E,0x55,0x23,0x74,0x56,0xBC,0x01,
0x39,0,18,0xF6,0x66,0x50,0xB0,0x77,0x5D,0xA1,0x78,0xE5,0x57,0x88,0xC0,0xF1,0x99,0x1F,0x4F,0x90,0x4F,
0x39,0,2,0xFF,0x01,
0x39,0,5,0xFE,0x01,0x06,0x00,0x00,
0x39,0,22,0xF1,0x00,0x00,0x01,0x00,0x02,0x03,0x00,0x04,0x05,0x00,0x06,0x07,0x01,0x0F,0x18,0x34,0x90,0x21,0x45,0xAA,0x01,
0x39,0,18,0xF2,0x55,0x3A,0xA8,0x66,0x4D,0x8E,0x67,0xD7,0x3E,0x77,0xA5,0xD0,0x78,0xFB,0x2B,0x80,0x2B,
0x39,0,22,0xF3,0x00,0x00,0x01,0x00,0x02,0x03,0x00,0x04,0x05,0x00,0x06,0x07,0x01,0x26,0xEA,0x33,0x17,0xAD,0x44,0x16,0x70,
0x39,0,18,0xF4,0x45,0xAC,0x1B,0x55,0xBD,0xFB,0x66,0x45,0xA7,0x77,0x0F,0x33,0x77,0x5D,0x8B,0x70,0x8B,
0x39,0,22,0xF5,0x02,0x00,0xEC,0x33,0x86,0xB3,0x33,0xCC,0xCD,0x33,0xCE,0xCF,0x44,0x2E,0x76,0x45,0xE9,0x58,0x55,0x9F,0xE1,
0x39,0,18,0xF6,0x66,0x2A,0x97,0x77,0x41,0x82,0x78,0xC8,0x39,0x88,0xA6,0xD2,0x99,0x00,0x31,0x90,0x31,
0x39,0,2,0xFF,0x01,
0x39,0,5,0xFE,0x01,0x07,0x00,0x00,
0x39,0,22,0xF1,0x00,0x00,0x01,0x00,0x02,0x03,0x00,0x04,0x05,0x00,0x06,0x07,0x00,0x08,0xCB,0x13,0x06,0x59,0x44,0x62,0x95,
0x39,0,18,0xF2,0x45,0xEB,0x63,0x66,0x0B,0x57,0x67,0x93,0x08,0x77,0x6A,0x99,0x77,0xC0,0xEF,0x70,0xEF,
0x39,0,22,0xF3,0x00,0x00,0x01,0x00,0x02,0x03,0x00,0x04,0x05,0x00,0x06,0x07,0x00,0x08,0x09,0x12,0xC8,0xF3,0x34,0xB5,0x00,
0x39,0,18,0xF4,0x44,0x4E,0xC6,0x55,0x70,0xBD,0x56,0xF6,0x70,0x66,0xCF,0xFD,0x77,0x1F,0x52,0x70,0x52,
0x39,0,22,0xF5,0x02,0x00,0xEC,0x33,0x54,0x6E,0x33,0x6F,0x70,0x33,0x71,0x72,0x34,0xE6,0x2F,0x45,0xAE,0x0F,0x55,0x59,0xB7,
0x39,0,18,0xF6,0x56,0xEE,0x5B,0x77,0x0B,0x51,0x78,0x91,0x05,0x88,0x6C,0x9D,0x88,0xC7,0xF8,0x80,0xF8,
0x39,0,2,0xFF,0x01,
0x39,0,5,0xFE,0x01,0x08,0x00,0x00,
0x39,0,22,0xF1,0x00,0x00,0x01,0x00,0x02,0x03,0x00,0x04,0x05,0x00,0x06,0x07,0x00,0x08,0x09,0x00,0x0A,0x55,0x00,0x78,0x79,
0x39,0,18,0xF2,0x34,0x8C,0x68,0x55,0x49,0x98,0x56,0xD1,0x48,0x66,0xA9,0xD0,0x67,0xFB,0x27,0x70,0x27,
0x39,0,22,0xF3,0x00,0x00,0x01,0x00,0x02,0x03,0x00,0x04,0x05,0x00,0x06,0x07,0x00,0x08,0x09,0x01,0x0A,0x15,0x12,0xD1,0x2A,
0x39,0,18,0xF4,0x33,0x15,0xD4,0x44,0xAB,0xF0,0x55,0x26,0xA9,0x66,0x11,0x30,0x66,0x59,0x87,0x60,0x87,
0x39,0,22,0xF5,0x02,0x00,0x55,0x22,0x56,0x57,0x22,0xD1,0xFA,0x33,0x10,0x13,0x33,0x14,0x8C,0x44,0x01,0x68,0x45,0xB5,0x16,
0x39,0,18,0xF6,0x55,0x4B,0xB1,0x66,0x6B,0xAB,0x67,0xDE,0x5C,0x77,0xBB,0xDC,0x88,0x07,0x2D,0x80,0x2D,
0x39,0,2,0xFF,0x01,
0x39,0,5,0xFE,0x01,0x09,0x00,0x00,
0x39,0,22,0xF1,0x00,0x00,0x01,0x00,0x02,0x03,0x00,0x04,0x05,0x00,0x06,0x07,0x00,0x08,0x09,0x00,0x0A,0x0B,0x00,0x0C,0x0F,
0x39,0,18,0xF2,0x00,0x50,0x51,0x34,0xF5,0xB1,0x45,0xF1,0x82,0x56,0xDE,0x11,0x66,0x3D,0x5D,0x60,0x5D,
0x39,0,22,0xF3,0x00,0x00,0x01,0x00,0x02,0x03,0x00,0x04,0x05,0x00,0x06,0x07,0x00,0x08,0x09,0x00,0x0A,0x0B,0x00,0x0C,0x0D,
0x39,0,18,0xF4,0x02,0xA8,0x37,0x34,0x7F,0x08,0x44,0x5A,0xD4,0x55,0x38,0x60,0x55,0x9C,0xB8,0x50,0xB8,
0x39,0,22,0xF5,0x00,0x00,0x01,0x00,0x02,0x03,0x01,0xE2,0x25,0x12,0x49,0x76,0x22,0xF8,0xF9,0x33,0x3A,0xAE,0x44,0x1C,0x64,
0x39,0,18,0xF6,0x45,0x96,0x10,0x56,0xCA,0x0D,0x66,0x52,0xAB,0x77,0x0C,0x2B,0x77,0x64,0x88,0x70,0x88,
0x39,0,2,0xFF,0x01,
0x39,0,2,0x9F,0x05,
0x39,0,2,0xF9,0x00,
0x39,0,4,0xFF,0x00,0x00,0x00,
0x39,0,2,0x9F,0x06,
0x39,0,3,0xFF,0x00,0x00,
0x39,0,2,0x9F,0x07,
//0x39,0,8,0xB2,0x10,0x10,0x10,0x10,0x04,0x00,0x98,
0x39,0,8,0xB2,0x04,0x04,0x04,0x04,0x04,0x00,0x98,
0x39,0,8,0xB3,0x15,0x15,0x15,0x15,0x04,0x00,0x9A,
0x39,0,8,0xB4,0x20,0x20,0x20,0x20,0x04,0x00,0x96,
0x39,0,8,0xB6,0x04,0x04,0x04,0x04,0x04,0x02,0x60,
0x39,0,8,0xB7,0x04,0x04,0x04,0x04,0x04,0x02,0x60,
0x39,0,33,0xB9,0x01,0x02,0x03,0x04,0x05,0x06,0x07,0x08,0x09,0x0A,0x0B,0x0C,0x0D,0x0E,0x0F,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,33,0xBA,0x01,0x02,0x03,0x04,0x05,0x06,0x07,0x08,0x09,0x0A,0x0B,0x0C,0x0D,0x0E,0x0F,0x10,0x11,0x12,0x13,0x14,0x15,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,33,0xBB,0x01,0x02,0x03,0x04,0x05,0x06,0x07,0x08,0x09,0x0A,0x0B,0x0C,0x0D,0x0E,0x0F,0x10,0x11,0x12,0x13,0x14,0x15,0x16,0x17,0x18,0x19,0x1A,0x1B,0x1C,0x1D,0x1E,0x1F,0x20,
0x39,0,33,0xBD,0x01,0x02,0x03,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,33,0xBE,0x01,0x02,0x03,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,31,0xC0,0x00,0x7A,0x7A,0x00,0x7A,0x7A,0x00,0x6A,0x46,0x00,0x26,0x1A,0x00,0x0F,0x0B,0x00,0x0B,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,31,0xC1,0x00,0x9A,0x9A,0x00,0x9A,0x9A,0x00,0x6A,0x46,0x00,0x26,0x1A,0x00,0x0F,0x0B,0x00,0x0B,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,31,0xC2,0x00,0x96,0x96,0x00,0x96,0x96,0x00,0x6A,0x46,0x00,0x26,0x1B,0x00,0x0F,0x0B,0x00,0x0B,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,7,0xC4,0x10,0x30,0x1C,0x00,0x1C,0x1C,
0x39,0,7,0xC5,0x22,0x60,0x60,0x22,0x60,0x60,
0x39,0,41,0xD6,0x0F,0xFF,0x07,0xFF,0x03,0x33,0x01,0x47,0x01,0x46,0x00,0xCD,0x00,0x66,0x00,0x3A,0x00,0x14,0x00,0x08,0x00,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,21,0xD7,0x03,0xFF,0x01,0xFF,0x00,0x00,0x00,0x00,0x03,0xFF,0x01,0xFF,0x00,0x00,0x00,0x00,0x03,0xFF,0x01,0xFF,
0x39,0,2,0x9F,0x0C,
0x39,0,9,0xB4,0xF0,0xC0,0xC0,0x1B,0x1B,0x00,0x00,0x16,
0x39,0,2,0x9F,0x08,
0x39,0,4,0xB2,0x10,0x00,0x02,
0x39,0,2,0xB4,0x11,
0x39,0,8,0xB5,0x00,0x02,0x01,0xFF,0x20,0x40,0xC0,
0x39,0,3,0xB6,0x58,0x03,
0x39,0,55,0xB7,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,
0x39,0,55,0xB8,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,
0x39,0,55,0xB9,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,
0x39,0,55,0xBA,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,
0x39,0,55,0xBB,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,
0x39,0,55,0xBC,0x44,0x2C,0x22,0x44,0x18,0x0E,0x43,0x00,0xF4,0x33,0xE6,0xD8,0x34,0xD3,0x2C,0x44,0x22,0x18,0x44,0x0E,0x00,0x33,0xF4,0xE6,0x33,0xD8,0xD3,0x44,0x2C,0x22,0x44,0x18,0x0E,0x43,0x00,0xF4,0x33,0xE6,0xD8,0x34,0xD3,0x2C,0x44,0x22,0x18,0x44,0x0E,0x00,0x33,0xF4,0xE6,0x33,0xD8,0xD3,
0x39,0,55,0xBD,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,
0x39,0,55,0xBE,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,
0x39,0,55,0xBF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,
0x39,0,55,0xC0,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,
0x39,0,55,0xC1,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,
0x39,0,55,0xC2,0x44,0x2C,0x22,0x44,0x18,0x0E,0x43,0x00,0xF4,0x33,0xE6,0xD8,0x34,0xD3,0x2C,0x44,0x22,0x18,0x44,0x0E,0x00,0x33,0xF4,0xE6,0x33,0xD8,0xD3,0x44,0x2C,0x22,0x44,0x18,0x0E,0x43,0x00,0xF4,0x33,0xE6,0xD8,0x34,0xD3,0x2C,0x44,0x22,0x18,0x44,0x0E,0x00,0x33,0xF4,0xE6,0x33,0xD8,0xD3,
0x39,0,55,0xC3,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,
0x39,0,55,0xC4,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,
0x39,0,55,0xC5,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,
0x39,0,55,0xC6,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,
0x39,0,55,0xC7,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,
0x39,0,55,0xC8,0x44,0x2C,0x22,0x44,0x18,0x0E,0x43,0x00,0xF4,0x33,0xE6,0xD8,0x34,0xD3,0x2C,0x44,0x22,0x18,0x44,0x0E,0x00,0x33,0xF4,0xE6,0x33,0xD8,0xD3,0x44,0x2C,0x22,0x44,0x18,0x0E,0x43,0x00,0xF4,0x33,0xE6,0xD8,0x34,0xD3,0x2C,0x44,0x22,0x18,0x44,0x0E,0x00,0x33,0xF4,0xE6,0x33,0xD8,0xD3,
0x39,0,10,0xC9,0x16,0x33,0x3D,0x01,0x00,0x0F,0xFF,0x00,0x00,
0x39,0,2,0xCA,0xF0,
0x39,0,6,0xCB,0x00,0x01,0x7C,0x42,0x00,
0x39,0,5,0xCC,0x00,0x01,0x00,0x1F,
0x39,0,4,0xCD,0x00,0x01,0x00,
0x39,0,33,0xCE,0x00,0x25,0x00,0xA9,0x01,0x9C,0x03,0x08,0x04,0xF4,0x07,0x65,0x0A,0x62,0x0D,0xEE,0x12,0x0C,0x16,0xC1,0x1C,0x10,0x21,0xFC,0x28,0x87,0x2F,0xB5,0x37,0x86,0x3F,0xFF,
0x39,0,12,0xCF,0xFC,0x01,0xFF,0xFF,0xFF,0xFF,0xFF,0xBA,0x4E,0xED,0x00,
0x39,0,53,0xD0,0x00,0x00,0x01,0xF1,0xEC,0x23,0xE4,0xDC,0x45,0xD7,0xDE,0x67,0xCB,0xC2,0x89,0xC0,0xC4,0xAB,0xC2,0xBC,0xCD,0xB5,0xAB,0xEF,0xAA,0xB4,0x00,0x00,0x01,0xFA,0xF1,0x23,0xEB,0xE4,0x45,0xE3,0xEB,0x67,0xDB,0xD1,0x89,0xCE,0xD0,0xAB,0xCC,0xC8,0xCD,0xC1,0xBA,0xEF,0xB9,0xB8,
0x39,0,53,0xD1,0x00,0x00,0x01,0xFF,0xF0,0x23,0xE8,0xE3,0x45,0xE1,0xE5,0x67,0xD7,0xCC,0x89,0xCE,0xD5,0xAB,0xCE,0xCA,0xCD,0xC4,0xBD,0xEF,0xB9,0xB7,0x00,0x00,0x01,0xF1,0xEB,0x23,0xE1,0xDD,0x45,0xD0,0xD0,0x67,0xBF,0xB1,0x89,0x9D,0x8A,0xAB,0x78,0x62,0xCD,0x49,0x30,0xEF,0x14,0x06,
0x39,0,53,0xD2,0x00,0x00,0x01,0xF5,0xEE,0x23,0xE8,0xE1,0x45,0xD6,0xD4,0x67,0xBF,0xB6,0x89,0xA6,0x99,0xAB,0x88,0x75,0xCD,0x60,0x47,0xEF,0x29,0x05,0x00,0x00,0x01,0xF4,0xEF,0x23,0xE7,0xE1,0x45,0xD7,0xD4,0x67,0xC2,0xB6,0x89,0xA4,0x91,0xAB,0x7A,0x63,0xCD,0x51,0x3B,0xEF,0x1E,0x01,
0x39,0,53,0xD3,0x00,0x00,0x01,0xFF,0xEC,0x23,0xE3,0xD9,0x45,0xD1,0xD6,0x67,0xC1,0xB7,0x89,0xB4,0xBE,0xAB,0xB3,0xAB,0xCD,0xA4,0x9A,0xEF,0x99,0xA1,0x00,0x00,0x11,0x0B,0xFC,0x23,0xF5,0xE4,0x45,0xDF,0xE4,0x67,0xCD,0xC5,0x89,0xBF,0xCD,0xAB,0xB7,0xB4,0xCD,0xAA,0xA4,0xEF,0xA6,0xA5,
0x39,0,53,0xD4,0x00,0x00,0x11,0x02,0xF2,0x23,0xE9,0xE0,0x45,0xDC,0xDD,0x67,0xCC,0xC2,0x89,0xC4,0xD0,0xAB,0xBF,0xB9,0xCD,0xB3,0xAC,0xEF,0xA8,0xA5,0x00,0x00,0x12,0x16,0x20,0x34,0x28,0x30,0x56,0x31,0x38,0x78,0x2F,0x29,0x9A,0x19,0x10,0xAB,0xFF,0xED,0xCD,0xD6,0xBC,0xEF,0xAF,0xB2,
0x39,0,53,0xD5,0x00,0x00,0x12,0x33,0x36,0x34,0x3F,0x45,0x56,0x49,0x4E,0x78,0x47,0x48,0x9A,0x3F,0x3C,0xBC,0x30,0x29,0xDD,0x15,0xFE,0xEF,0xDE,0xBE,0x00,0x00,0x12,0x18,0x26,0x34,0x31,0x39,0x56,0x3D,0x42,0x78,0x3B,0x38,0x9A,0x2D,0x22,0xBC,0x0E,0x0A,0xCD,0xF8,0xE0,0xEF,0xC9,0xB9,
0x39,0,53,0xD6,0x80,0x00,0x02,0xD9,0x08,0x34,0x13,0x1A,0x46,0xE9,0x3C,0x78,0x76,0x8C,0x9A,0xA4,0xBE,0xBC,0xCE,0xD8,0xDE,0xD7,0xD7,0xF1,0xF4,0x16,0x80,0x00,0x02,0xCF,0x01,0x34,0x0A,0x1A,0x46,0xEE,0x44,0x78,0x7B,0x90,0x9A,0xAC,0xC7,0xBC,0xD5,0xD8,0xDE,0xE3,0xED,0xF0,0xF4,0xFC,
0x39,0,27,0xD7,0x80,0x00,0x02,0xF1,0x1B,0x34,0x27,0x2A,0x46,0xFF,0x5D,0x78,0x94,0xAD,0x9A,0xC7,0xDC,0xBC,0xE9,0xE9,0xDE,0xE7,0xE4,0xF1,0xF4,0x06,
0x39,0,18,0xD8,0x80,0x96,0x91,0x8D,0x8B,0x8A,0x96,0x90,0x8E,0x87,0x90,0x96,0x92,0x85,0x8F,0x94,0x96,
0x39,0,2,0x9F,0x09,
0x39,0,3,0xB2,0x9C,0x09,
0x39,0,9,0xB3,0x00,0x00,0x00,0x00,0x80,0x80,0x80,0x80,
0x39,0,16,0xB4,0x76,0xFF,0xDD,0x43,0x84,0x48,0x32,0x47,0x22,0x11,0x85,0x0D,0x00,0xAC,0x01,
0x39,0,35,0xC0,0x00,0x00,0x01,0x64,0x9C,0xC8,0x18,0x55,0x52,0x72,0x9A,0xB8,0x5A,0xE0,0xF4,0x26,0x58,0x00,0x00,0x01,0x64,0x9C,0xC8,0x18,0x55,0x52,0x72,0x9A,0xB8,0x5A,0xE0,0xF4,0x26,0x58,
0x39,0,29,0xC1,0xFF,0xF5,0xED,0xE5,0xDD,0xD6,0xD0,0xD0,0xCD,0x0F,0xC5,0xC3,0xC3,0xC3,0x00,0x0F,0x13,0x16,0x1A,0x20,0x23,0x25,0x2D,0x00,0x2D,0x2D,0x2D,0x2D,
0x39,0,29,0xC2,0xFF,0xF5,0xED,0xE5,0xDD,0xD6,0xD3,0xCD,0xC9,0x0F,0xC9,0xC0,0xC0,0xC0,0x00,0x0F,0x15,0x15,0x1B,0x20,0x2F,0x35,0x35,0x00,0x38,0x38,0x38,0x38,
0x39,0,29,0xC3,0xFF,0xF5,0xED,0xE5,0xDE,0xD6,0xD3,0xCD,0xC9,0x0F,0xC9,0xC0,0xC0,0xC0,0x00,0x0F,0x13,0x15,0x1B,0x20,0x2F,0x35,0x35,0x00,0x38,0x38,0x38,0x38,
0x39,0,29,0xC4,0xFF,0xF5,0xED,0xE5,0xDE,0xD6,0xD3,0xCD,0xC9,0x0F,0xC9,0xC0,0xC0,0xC0,0x00,0x0F,0x13,0x15,0x1B,0x20,0x2F,0x35,0x35,0x00,0x38,0x38,0x38,0x38,
0x39,0,29,0xC5,0xFF,0xF5,0xED,0xE5,0xDD,0xD6,0xD3,0xCD,0xC9,0x0F,0xC9,0xC0,0xC0,0xC0,0x00,0x0F,0x15,0x15,0x1B,0x20,0x2F,0x35,0x35,0x00,0x38,0x38,0x38,0x38,
0x39,0,29,0xC6,0xFF,0xF5,0xED,0xE8,0xE0,0xD6,0xD3,0xCD,0xC9,0x0F,0xC9,0xC0,0xC0,0xC0,0x00,0x0F,0x15,0x15,0x1B,0x20,0x2F,0x35,0x35,0x00,0x38,0x38,0x38,0x38,
0x39,0,29,0xC7,0xFF,0xF5,0xED,0xE8,0xE0,0xD6,0xD3,0xCD,0xC9,0x0F,0xC9,0xC0,0xC0,0xC0,0x00,0x0F,0x15,0x15,0x1B,0x20,0x2F,0x35,0x35,0x00,0x38,0x38,0x38,0x38,
0x39,0,29,0xC8,0xFF,0xF5,0xED,0xE8,0xE0,0xD6,0xD3,0xCD,0xC9,0x0F,0xC9,0xC0,0xC0,0xC0,0x00,0x0F,0x15,0x15,0x1B,0x20,0x2F,0x35,0x35,0x00,0x38,0x38,0x38,0x38,
0x39,0,29,0xC9,0xFF,0xF5,0xED,0xE8,0xE0,0xD6,0xD3,0xCD,0xC9,0x0F,0xC9,0xC0,0xC0,0xC0,0x00,0x0F,0x15,0x15,0x1B,0x20,0x2F,0x35,0x35,0x00,0x38,0x38,0x38,0x38,
0x39,0,29,0xCA,0xFF,0xF5,0xED,0xE5,0xDD,0xD6,0xD3,0xCD,0xC9,0x0F,0xC9,0xC0,0xC0,0xC0,0x00,0x0F,0x15,0x15,0x1B,0x20,0x2F,0x35,0x35,0x00,0x38,0x38,0x38,0x38,
0x39,0,29,0xCB,0xFF,0xF3,0xF0,0xE8,0xDD,0xD8,0xD5,0xD0,0xCD,0x0F,0xC5,0xC3,0xC3,0xC3,0x00,0x08,0x15,0x18,0x1F,0x20,0x23,0x25,0x2D,0x00,0x2D,0x2D,0x2D,0x2D,
0x39,0,29,0xCC,0xFF,0xF3,0xF0,0xE8,0xDD,0xD8,0xD5,0xD0,0xCD,0x0F,0xC5,0xC3,0xC3,0xC3,0x00,0x08,0x0F,0x12,0x1F,0x20,0x23,0x25,0x2D,0x00,0x2D,0x2D,0x2D,0x2D,
0x39,0,29,0xCD,0xFF,0xF3,0xF0,0xE8,0xDD,0xD8,0xD5,0xD0,0xCD,0x0F,0xC5,0xC3,0xC3,0xC3,0x00,0x08,0x17,0x18,0x1F,0x20,0x23,0x25,0x2D,0x00,0x2D,0x2D,0x2D,0x2D,
0x39,0,29,0xCE,0xFF,0xF3,0xF0,0xE8,0xDD,0xD8,0xD5,0xD0,0xCD,0x0F,0xC5,0xC3,0xC3,0xC3,0x00,0x08,0x17,0x18,0x1F,0x20,0x23,0x25,0x2D,0x00,0x2D,0x2D,0x2D,0x2D,
0x39,0,29,0xCF,0xFF,0xF5,0xF3,0xED,0xDE,0xD8,0xCD,0xC8,0xCF,0x0F,0xCD,0xC5,0xC3,0xC3,0x00,0x08,0x0D,0x0F,0x12,0x15,0x17,0x18,0x1D,0x00,0x1F,0x20,0x25,0x2D,
0x39,0,29,0xD1,0xFF,0xF5,0xF3,0xED,0xDE,0xD8,0xCD,0xC8,0xCF,0x0F,0xCD,0xC5,0xC3,0xC3,0x00,0x08,0x0D,0x0F,0x12,0x15,0x17,0x18,0x1D,0x00,0x1F,0x20,0x25,0x2D,
0x39,0,29,0xD2,0xFF,0xF5,0xF3,0xED,0xDE,0xD8,0xCD,0xC8,0xCF,0x0F,0xCD,0xC5,0xC3,0xC3,0x00,0x08,0x0D,0x0F,0x12,0x15,0x17,0x18,0x1D,0x00,0x1F,0x20,0x25,0x2D,
0x39,0,29,0xD3,0xFF,0xF5,0xF3,0xED,0xDE,0xD8,0xCD,0xC8,0xCF,0x0F,0xCD,0xC5,0xC3,0xC3,0x00,0x08,0x0D,0x0F,0x12,0x15,0x17,0x18,0x1D,0x00,0x1F,0x20,0x25,0x2D,
0x39,0,29,0xD4,0xFF,0xF5,0xF3,0xED,0xDE,0xD8,0xCD,0xC8,0xCF,0x0F,0xCD,0xC5,0xC3,0xC3,0x00,0x0F,0x12,0x0F,0x12,0x15,0x17,0x18,0x1D,0x00,0x1F,0x20,0x25,0x2D,
0x39,0,17,0xD5,0x17,0xF9,0xFE,0xFD,0x05,0x00,0x00,0x00,0x17,0xF9,0xF8,0xFE,0x00,0x00,0x00,0x00,
0x39,0,17,0xD6,0x18,0xF5,0xF8,0x03,0x00,0x00,0x00,0x00,0x17,0xEB,0xED,0xEF,0x00,0x00,0x00,0x00,
0x39,0,13,0xD7,0x05,0x00,0x80,0x00,0x80,0xAF,0x00,0x80,0x00,0x80,0x03,0xFF,
0x39,0,17,0xD8,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
0x39,0,6,0xEE,0x30,0x10,0x00,0x10,0xFF,
0x39,0,2,0x9F,0x0A,
0x39,0,12,0xB2,0x1F,0x00,0x10,0x01,0x00,0x07,0x00,0x00,0x00,0x11,0x00,
0x39,0,43,0xB3,0x10,0x10,0x00,0x10,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x10,0x00,0x10,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x3F,0x00,0x00,0x00,0x00,0x00,0x00,0x3F,0x00,0x00,
0x39,0,43,0xB4,0x00,0x00,0x00,0x00,0x3F,0x00,0x00,0x00,0x00,0x00,0x00,0x3F,0x00,0x00,0x00,0x00,0x00,0x00,0x3F,0x00,0x00,0x00,0x00,0x00,0x00,0x3F,0x00,0x00,0x00,0x00,0x00,0x00,0x3F,0x00,0x00,0x00,0x00,0x00,0x00,0x3F,0x00,0x00,
0x39,0,43,0xB5,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x10,0x00,0x10,0x10,0x00,0x00,0x10,0x10,0x00,0x10,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3F,0x00,0x00,0x00,0x00,0x00,0x00,0x3F,0x00,0x00,
0x39,0,12,0xBE,0x00,0x1F,0xFF,0x13,0x91,0x0F,0x04,0x00,0x24,0x80,0xFF,
0x39,0,2,0x9F,0x0B,
0x39,0,10,0xB2,0x01,0x3F,0x3F,0x0F,0x3F,0x0F,0x5F,0x0F,0x0F,
0x39,0,49,0xB9,0x32,0x00,0x00,0x00,0x00,0x00,0x6B,0x54,0x24,0x1C,0xB0,0x14,0xC8,0x5C,0x24,0x1C,0xB0,0xFF,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xFF,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xFF,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,49,0xBA,0x32,0x00,0x00,0x00,0x00,0x00,0x54,0x69,0x24,0x1C,0xB0,0x14,0xC8,0x5C,0x24,0x1C,0xB0,0xFF,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xFF,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xFF,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,49,0xBC,0x32,0x00,0x00,0x00,0x00,0x00,0x4b,0x4b,0x24,0x1C,0xB0,0x14,0xD1,0x65,0x24,0x1C,0xB0,0xFF,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xFF,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xFF,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,49,0xBE,0x32,0x00,0x00,0x00,0x00,0x00,0x20,0x20,0x20,0x1C,0x33,0x00,0x00,0x00,0x00,0x20,0x20,0xFF,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xFF,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xFF,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,20,0xC6,0x8F,0x04,0x04,0x04,0x04,0xFF,0xFF,0xFF,0xFF,0x00,0x22,0x22,0x22,0x22,0x00,0x1E,0x1E,0x1E,0x1E,
0x39,0,20,0xC7,0x0F,0x04,0x04,0x04,0x04,0xFF,0xFF,0xFF,0xFF,0x00,0x22,0x22,0x22,0x22,0x00,0x1E,0x1E,0x1E,0x1E,
0x39,0,16,0xC8,0xF9,0x05,0x05,0xB0,0xE0,0xB0,0x50,0xBA,0xF0,0xB0,0xE0,0xB0,0x20,0xD0,0x50,
0x39,0,2,0x9F,0x0D,
0x39,0,16,0xB2,0x25,0x10,0x21,0x01,0x02,0x10,0x00,0x00,0x16,0x10,0x00,0x00,0x01,0xAA,0x90,
0x39,0,2,0xB3,0xB0,
0x39,0,13,0xB5,0x00,0x24,0x07,0x01,0x00,0x00,0x00,0x00,0x20,0x04,0xEE,0x21,
0x39,0,4,0xB6,0x02,0x12,0x22,
0x39,0,5,0xB7,0x20,0xF0,0xC0,0xE0,
0x39,0,13,0xB8,0x20,0xF0,0xC0,0xE0,0x20,0xF0,0xC0,0xE0,0x20,0xF0,0xC0,0xE0,
0x39,0,5,0xB9,0x01,0x01,0x01,0x01,
0x39,0,3,0xBA,0x00,0x00,
0x39,0,2,0xBB,0x01,
0x39,0,21,0xBC,0x0F,0xFF,0x07,0xFF,0x03,0x33,0x01,0x47,0x01,0x46,0x00,0xCD,0x00,0x66,0x00,0x3A,0x00,0x14,0x00,0x08,
0x39,0,6,0xBD,0x02,0x00,0x02,0x06,0x5B,
0x39,0,12,0xC7,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x2A,0x00,
0x39,0,2,0x48,0x03,  //00 cmd  0x03 vdo
//// bist mode 
//0x39,0,2,0x9F,0x01,
////0x39,0,5,0xC6,0x01,0x20,0x18,0x02,
//0x39,0,3,0xC6,0x03,0x08,
0x39,0,1,0x11,
//0x39,0,3,0x51,0x00,0x00,
0x39,0,2,0x53,0xE0,
0x39,0,1,0x35,
//0x39,0,1,0x29,

#endif
#if DDIC_FPS_SETTING 
0x39,0,2,0x9F,0x04, 
0x39,0,14,0xB5,0x00,0x17,0x27,0x1B,0x17,0x00,0x75,0x75,0x10,0x3B,0x08,0xA8,0x48,  // 0x3B,0x10,0xB8,0x40,(美版ANDROID 13放久过后指纹解会失效)
//1226 0x3B,0x08,0xA8,0x48(ANDROID 13+++/14+++) 0x3B,0x10,0xA8,0x50(ANDROID 13++/14++) 0x3B,0x00,0xAF,0x58(ANDROID 13++/14+)
//1225 0x3B,0x08,0xA0,0x48(ANDROID 13+++/14++) 0x3B,0x10,0xA8,0x48(ANDROID 13++/14++) 0x3B,0x10,0xA8,0x4F(ANDROID 13++/14++) 0x3B,0x10,0xA0,0x48(ANDROID 13++/14++) 0x3B,0x10,0xB0,0x4F(ANDROID 13++/14+) , 0x3B,0x10,0xB8,0x4F(ANDROID 13++/14+)   0x3B,0x18,0xB8,0x4F(ANDROID 13++/14) 0x3B,0x08,0x98,0x2F(ANDROID 13++/14-); 0x3B,0x28,0xB8,0x4F(ANDROID 13++/14--);   , 0x3B,0x20,0xB0,0x40 (ANDROID 13/14  JP NG)
//1222 0x2B,0xF0,0x98,0x7F(ALL OK)  0x2B,0xF0,0x98,0x2F (ALL OK 2nd)  0x2B,0xF0,0x98,0x00, (ALL OK 3rd )0x2B,0xF0,0x9F,0x3F   0x2B,0xDF,0x8F,0x4F(ANDROID 12 FAIL )
//1214  0x2B,0xFF,0x9F,0x5F 0x2B,0xFF,0xCF,0x5F  
//ANDROID 14  0x2B,0xF0,0x90,0x20  秒解  LAST VERSION 0x3B,0x3F,0xDF,0x6F  
// 1211 fail FOR ALL VERSION 0x3B,0x3F,0xEF,0x6F; 0x3B,0x2F,0xDF,0x5F; 0x3B,0x1F,0xCF,0x4F; 0x3B,0x1F,0xCF,0x4F; 0x3B,0x0F,0xBF,0x3F; 0x2B,0xFF,0xAF,0x3F  
0x39,0,18,0xBE,0x00,0xCF,0xFF,0xFF,0xFF,0x3F,0xFF,0xFF,0xFF,0x3F,0xFF,0xFF,0xFF,0x3F,0xFF,0xFF,0xFF,
0x39,0,46,0xE9,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0x00,0xFF,0xFF,0xFF,0x3F,0x3F,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,
0x39,0,28,0xEA,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,
0x39,0,46,0xEB,0xFF,0xFF,0xFF,0x00,0xFF,0xFF,0x00,0xFF,0xFF,0x00,0xFF,0xFF,0xFF,0x3F,0x3F,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,
0x39,0,28,0xEC,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,
0x39,0,46,0xED,0xFF,0xFF,0xFF,0x00,0xFF,0xFF,0x00,0xFF,0xFF,0x00,0xFF,0xFF,0xFF,0x3F,0x3F,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,
0x39,0,28,0xEE,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,0x33,0xFF,0xFF,
0x39,0,10,0xF8,0x1E,0xE0,0xE0,0xE0,0x00,0x18,0x15,0x00,0xE0,
0x39,0,10,0xF9,0xE1,0x18,0x15,0x00,0xF0,0xF8,0xF0,0xEE,0x00,
0x39,0,10,0xFA,0x1E,0xE0,0xE0,0xE0,0x00,0x18,0x15,0x00,0xE0,
0x39,0,2,0x9F,0x05,
0x39,0,13,0xB4,0x02,0x0F,0x3E,0x00,0x00,0x10,0x06,0x00,0x00,0x02,0x40,0x8D,
0x39,0,41,0xE6,0x0F,0xFF,0x07,0xFF,0x03,0x33,0x01,0x47,0x01,0x46,0x00,0xCD,0x00,0x66,0x00,0x3A,0x00,0x14,0x00,0x08,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,31,0xE7,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,41,0xE8,0x0F,0xFF,0x0F,0xFF,0x0F,0xFF,0x0F,0xFF,0x0F,0xFF,0x0C,0xF0,0x09,0x71,0x07,0x54,0x04,0x8C,0x03,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
//0x39,0,41,0xE8,0x01,0xFF,0x00,0x1F,0x00,0x2F,0x00,0x1F,0x00,0x1F,0x0C,0xF0,0x09,0x71,0x07,0x54,0x04,0x8C,0x03,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x39,0,31,0xE9,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,


#endif
};

#endif


/**
* @brief  panel init
* @param  none
* @retval none
*/
static void app_init_panel(void)
{
    /* reset panel*/
    app_tx_panel_reset();
#if PANEL_INIT_CODE_ARRAY
	send_panel_init_code(sizeof(panel_init_code), (uint8_t *) panel_init_code);
#endif
	hal_gpio_init_output(IO_PAD_AP_PWMEN, IO_LVL_HIGH);	
    delayMs(90);
#if AP_SWIRE_OUTPUT
    hal_swire_enable(true);
    hal_swire_set_pulse(SWIRE_DEFAULT_PULSE);
#endif
//	hal_gpio_init_output(IO_PAD_AP_SWIRE, IO_LVL_HIGH);	
//	Gpio_swire_output(2, 40);  

//	TAU_LOGD("Panel init!\n\r");
}

#if TX_CMD_MODE_WITHOUT_TE
/**
* @brief  MIPI RX事件处理函数,demo code 用于command mode 输出发送数据（模式1）
* @param  event:RX事件
* @param  data: user data
* @retval none
*/
static void app_rx_event_cb(hal_rx_event_e event, void *data)
{
    if (panel_display_done && event == HAL_RX_LINE_EVENT)
    {
        hal_dsi_tx_ctrl_gen_a_frame();
    }
}
#endif

#if TX_USE_CMD_MODE
/**
* @brief  TE引脚作为GPIO 输入回调函数,demo code 用于command mode 输出发送数据（模式2）
* @param  none
* @retval none
*/
static void app_tx_cmd_panel_te_cb(void *data)
{
    if (panel_display_done)
    {
        //delayUs(25); /* 撕裂调试 */
        hal_dsi_tx_ctrl_gen_a_frame();
    }
}

/**
* @brief  注册屏端TE信号输入引脚回调函数
* @param  pad :TE输入pad
* @param  trig:触发中断沿配置
* @retval none
*/
static void app_tx_cmd_app_init_panel_te_int(io_pad_e pad, sys_cfg_trigger_e trig)
{
    /*1.关闭中断*/
    hal_gpio_ctrl_eint(pad, DISABLE);

    /*2.中断初始化*/
    hal_gpio_init_eint(pad, trig);

    /*3.注册回调*/
    hal_gpio_reg_eint_cb(pad, app_tx_cmd_panel_te_cb);

    /*4.使能中断*/
    hal_gpio_ctrl_eint(pad, ENABLE);
}
#endif

/**
* @brief  mipi rx 初始化
* @param  none
* @retval none
*/
static void app_mipi_rx_init(void)
{
    if (g_rx_ctrl_handle == NULL)
    {
        /* 创建rx   ctrl handle */
        g_rx_ctrl_handle = hal_dsi_rx_ctrl_create_handle();
    }
    /* 配置参数 */
    g_rx_ctrl_handle->base_info.src_w = INPUT_WIDTH;
    g_rx_ctrl_handle->base_info.src_h = INPUT_HEIGHT;
    g_rx_ctrl_handle->base_info.dst_w = OUTPUT_WIDTH;
    g_rx_ctrl_handle->base_info.dst_h = OUTPUT_HEIGHT;
    g_rx_ctrl_handle->base_info.src_frate = INPUT_FRAME_RATE;
    g_rx_ctrl_handle->base_info.src_mode = INPUT_DATA_MODE;
    g_rx_ctrl_handle->base_info.dst_mode = OUTPUT_DATA_MODE;
    g_rx_ctrl_handle->rx_color_mode = INPUT_COLOR_MODE;
    g_rx_ctrl_handle->rx_lanes = INPUT_MIPI_LANE_NUM;
    g_rx_ctrl_handle->rx_nonburst_models = INPUT_VIDEO_MODEL; /* 可不配置 */
    g_rx_ctrl_handle->compress_en = INPUT_COMPRESS;
    g_rx_ctrl_handle->rx_hsclk_rate = INPUT_MIPI_LANE_RATE;
    g_rx_ctrl_handle->cus_dcs_entry_table = g_cus_rx_dcs_execute_table; /* 注册 DCS处理列表 */
    g_rx_ctrl_handle->rx_dcs_read_entry = ap_dcs_read; /* 注册dsc read 回调函数,可选,此函数为空时由cus_dcs_entry_table执行 */
//	g_rx_ctrl_handle->hight_performan_mode=HIGHT_PERFORMAN_L2;
	g_rx_ctrl_handle->extra_info.crop_info.top =12;  //4 8 的倍数
	g_rx_ctrl_handle->extra_info.crop_info.enable=1;	
#if RX_RESOLUTION_CHANGE_ENABLE
    g_rx_ctrl_handle->pps_update_entry = pps_update_handle;
#endif
    /* 提前预置PPS,  AP 有PPS cmd也会更新 */
    if (g_rx_ctrl_handle->compress_en == true)
    {
        hal_dsi_rx_ctrl_pre_init_pps(g_rx_ctrl_handle, pps, 128);
    }

    /* 初始化rx ctrl */
    hal_dsi_rx_ctrl_init(g_rx_ctrl_handle);

#if RX_READ_HW_ACK
    /* 配置硬件回复 */
    app_set_dcs_hw_ack();
#endif

#if TX_CMD_MODE_WITHOUT_TE
    /* 注册接收一帧帧头事件回调,每接收一帧数据TX再往外发一帧 */
    //hal_dsi_rx_ctrl_register_callback(g_rx_ctrl_handle, app_rx_event_cb, HAL_RX_FS_EVENT, true, NULL);
    /* 注册接收第0行数据事件,接收到数据后再往外发送数据,确保不撕裂 */
    uint32_t line = 0;
    hal_dsi_rx_ctrl_register_callback(g_rx_ctrl_handle, app_rx_event_cb, HAL_RX_LINE_EVENT, true, &line);
#endif

#if RX_START_WITHOUT_RST
    /* 等待ap reset置位再启动rx,否则容易收到错误数据 */
    hal_dsi_rx_ctrl_start(g_rx_ctrl_handle);
#else
    /* 注册RX start callback,确认RX LP11时再启动RX,防止接收错误数据 */
    hal_gpio_set_ap_reset_int(ENABLE, app_mipi_rx_start_cb, DETECT_HIGH_LVL);
#endif
	TAU_LOGD("rx init!\n\r");
}

/**
* @brief  mipi tx 初始化
* @param  none
* @retval none
*/
static void app_mipi_tx_init(void)
{
    if (g_tx_ctrl_handle == NULL)
    {
        g_tx_ctrl_handle = hal_dsi_tx_ctrl_create_handle();
    }
    g_tx_ctrl_handle->channel_id = OUTPUT_VC;
    g_tx_ctrl_handle->lane_num = OUTPUT_LANE_NUMBER;
    g_tx_ctrl_handle->vid_mode = OUTPUT_VIDEO_MODEL;
    g_tx_ctrl_handle->cmd_tx_type = TX_INIT_TYPE;
    g_tx_ctrl_handle->dpi_vsa = OUTPUT_VSA;
    g_tx_ctrl_handle->dpi_vbp = OUTPUT_VBP;
    g_tx_ctrl_handle->dpi_vfp = OUTPUT_VFP;
    g_tx_ctrl_handle->dpi_hsa = OUTPUT_HSA;
    g_tx_ctrl_handle->dpi_hbp = OUTPUT_HBP;
    g_tx_ctrl_handle->dpi_hfp = OUTPUT_HFP;
    g_tx_ctrl_handle->base_info.src_w = INPUT_WIDTH;
    g_tx_ctrl_handle->base_info.src_h = INPUT_HEIGHT;
    g_tx_ctrl_handle->base_info.dst_w = OUTPUT_WIDTH;
    g_tx_ctrl_handle->base_info.dst_h = OUTPUT_HEIGHT;
    g_tx_ctrl_handle->base_info.src_frate = INPUT_FRAME_RATE;
    g_tx_ctrl_handle->base_info.src_mode = INPUT_DATA_MODE;
    g_tx_ctrl_handle->base_info.dst_mode = OUTPUT_DATA_MODE;
	g_tx_ctrl_handle->tx_frame_rate=58;
//	g_tx_ctrl_handle->tx_lane_lp = 2;
	
    /* 初始化屏时每一条LP CMD都退出LPDT 再进入发送下一条 */
    /* 解决FT8720 TDDI 显示翻转问题 */
 //   g_tx_ctrl_handle->lp_exit_lpdt = true;

    hal_dsi_tx_ctrl_init(g_tx_ctrl_handle);
//	hal_dsi_tx_ctrl_set_cus_sync_line(g_tx_ctrl_handle,1200);  //1200

    /* FIXME set tear on*/
  //  hal_dsi_tx_ctrl_set_tear_mode(g_tx_ctrl_handle, TE_60HZ_MODE);

    /* AP 没有发送数据时默认的显示颜色, 量产为0 0 0(黑色), 配置其他颜色仅为debug使用 */
    hal_dsi_tx_ctrl_set_overwrite_rgb(0x00, 0x00, 0x00);
	TAU_LOGD("tx init!\n\r");
}

#if !RX_START_WITHOUT_RST
/**
* @brief  mipi rx start函数,开启AP RSTN等待启动配置后使用
* @param  none
* @retval none
*/
static void app_mipi_rx_start_cb(void *data)
{
    /* RX start */
    hal_dsi_rx_ctrl_start(g_rx_ctrl_handle);
    /* close cb */
    hal_gpio_set_ap_reset_int(DISABLE, NULL, DETECT_HIGH_LVL);
    TAU_LOGD("rx start\n");
}
#endif

void Panel_CCM(void)
{
	ccm_coef_t ccm;
	ccm.coef_c00 = 255;	// 260
	ccm.coef_c01 = 0;
	ccm.coef_c02 = 0;
	ccm.coef_c10 = 0;
	ccm.coef_c11 = 246;	// 247
	ccm.coef_c12 = 0;
	ccm.coef_c20 = 0;
	ccm.coef_c21 = 0;
	ccm.coef_c22 = 247;  //248

	hal_dsi_tx_ctrl_set_ccm(&ccm);
}


/**
* @brief  mipi tx 启动
* @param  none
* @retval none
*/
static void app_mipi_tx_start(void)
{
	// TAU_LOGD("tx_start \n");
    /* Init panel */
    app_init_panel();
    /* TX start */
    hal_dsi_tx_ctrl_start(g_tx_ctrl_handle);

#if RX_WAIT_TEAR_ON
    te_mode_e default_te = sg_ap_set_tear_on ? TE_60HZ_MODE : TE_USER_MODE;
    hal_dsi_tx_ctrl_set_tear_mode(g_tx_ctrl_handle, default_te);
#else
    hal_dsi_tx_ctrl_set_tear_mode(g_tx_ctrl_handle, TE_60HZ_MODE);
#endif

    panel_display_done = true;
	 if(g_tx_ctrl_handle->base_info.src_w==1008)
	{
		hal_dsi_rx_ctrl_pre_init_pps(g_rx_ctrl_handle, pps_fhd, 128);
		hal_dsi_rx_ctrl_toggle_resolution(g_rx_ctrl_handle);
		g_resolution_change = false;
	//	TAU_LOGD("pps_update!!\r\n");
	}
  //   soft_te_timer_init();
    delayMs(80);
//	Panel_CCM();
//	 delayMs(20);
    /* Display on */
    hal_dsi_tx_ctrl_write_cmd(0x05, 0, 1, 0x29);

#if AP_SWIRE_OUTPUT
    hal_swire_set_pulse(SWIRE_DEFAULT_PULSE);
#endif

#if (TX_USE_CMD_MODE & (!TX_CMD_MODE_WITHOUT_TE))
    // hal_dsi_tx_ctrl_gen_a_frame(); /* FIXME */
    app_tx_cmd_app_init_panel_te_int(IO_PIN_14, DETECT_RISING_EDGE); /* 注册屏端TE中断 */
#endif

    TAU_LOGD("tx_start \n");
}

/**
* @brief  ap rstn 拉高中断回调,用于息屏唤醒
* @param  none
* @retval none
*/
static void ap_rstn_pull_high_cb(void *data)
{
    /* system resume begin */
    sg_system_resume = true;
    /* 关闭AP reset检查     */
    hal_gpio_set_ap_reset_int(DISABLE, NULL, DETECT_RISING_EDGE);
}

/**
* @brief  ap rstn 拉高中断回调,用于息屏待机
* @param  none
* @retval none
*/
static void ap_rstn_pull_down_cb(void *data)
{
	 TAU_LOGD("ap_rstn_pull_down_cb\n");
    sg_system_suspend = true;
    /* 关闭AP reset检查     */
    hal_gpio_set_ap_reset_int(DISABLE, NULL, DETECT_RISING_EDGE);
//    TAU_LOGD("ap_rstn_pull_down_cb\n");
}

/**
* @brief  GPIO初始化配置,根据实际原理图提前配置IO功能以及状态,默认功能可不配置
*         TP相关I2C/SPI 在tp_transfer.c,也可以挪到此函数初始化
* @param  none
* @retval none
*/
void app_gpio_init(void)
{
    io_pad_attr_t attrs[] =
    {
        {IO_PIN_8,  PIN8_MODE_GPIO7,     IO_IOE_OUTPUT, IO_LVL_LOW},/* PIN_8(TD_RSTN), GPIO,输出,低电平 */
        {IO_PIN_17, PIN17_MODE_GPIO8,   IO_IOE_OUTPUT, IO_LVL_LOW}, /* PIN_17(PWMEN), GPIO,输出,低电平 */
        {IO_PIN_16, PIN16_MODE_GPIO2,   IO_IOE_OUTPUT, IO_LVL_LOW}, /* PIN_16(AP_INT),GPIO,输出,低电平 */
#if (TX_USE_CMD_MODE & (!TX_CMD_MODE_WITHOUT_TE))
        {IO_PIN_14, PIN14_MODE_GPIO24,   IO_IOE_INPUT, IO_LVL_NONE}, /* PIN_29(AP_TE), cmd mode输出, 并且看屏TE,配置AP TE为GPIO输入 */
#endif
        {IO_PIN_29, PIN29_MODE_TEAR,    IO_IOE_NONE, IO_LVL_NONE},  /* PIN_29(AP_TE), 硬件TEAR输出模式 */

    };
    uint8_t size = sizeof(attrs) / sizeof(io_pad_attr_t);
    hal_gpio_config_pad(attrs, size);
}


/**
* @brief  显示相关模块初始化,包括MIPI RX/TX/PWM/SWIRE/GPIO等
* @param  none
* @retval none
*/
void app_display_init(void)
{
    /* mipi rx初始化 */
    app_mipi_rx_init();
    /* VCC 主供电,等待VCC Power Ready,此时RX初始化完成可以响应MIPI命令 */
    if (MAIN_POWER_SELECT == PWR_SEL_VCC)
    {
		
        while (hal_pwr_get_vcc_power_ready() == false);
    }

    /* GPIO 初始化   */
    app_gpio_init();
//TAU_LOGD("app_gpio_init \n");
    /* 背光初始化      */
#if AP_SWIRE_OUTPUT
    hal_swire_init();   /*  swire init */
    hal_swire_set_timer(TIMER_NUM0, 8, true); /* swire连续发送,绑定timer进行发送 */
#endif
#if ANALOG_PWM_OUTPUT
    if (hal_pwm_init(PWM_FREQUENCY, PWM_DUTY_STEP))
    {
        hal_pwm_enable(true);
        hal_pwm_set_elvcc_output(true);
    }
#endif

    /* mipi tx 初始化*/
    app_mipi_tx_init();
//	soft_te_timer_init();
#if TX_START_AFTER_APRST
    TAU_LOGD("wait exit sleep mode\n");
#else
    app_mipi_tx_start();
#endif
}

/**
* @brief  系统resume
* @param  sleep_mode: sleep 模式
* @retval none
*/
static void app_system_resume(pwr_sleep_mode_e sleep_mode)
{
    /* 退出sleep mode, 电源切换 */
    hal_pwr_exit_sleep_mode();

    /* display resume */
    app_display_init();

#if TOUCH_ENABLE
    /* touch resume */
    app_tp_write_other_operations(NULL, 0);
#endif
    TAU_LOGD("system resume\n");
}

/**
* @brief  系统suspend,进入sleep mode
* @param  sleep_mode: sleep 模式
* @retval none
*/
static void app_system_suspend(pwr_sleep_mode_e sleep_mode)
{
//	TAU_LOGD("SLEEP_MODE\n");
    /* 关闭图像通路 */
    hal_dsi_tx_ctrl_stop(g_tx_ctrl_handle);
    hal_dsi_tx_ctrl_deinit(g_tx_ctrl_handle);
    hal_dsi_rx_ctrl_stop(g_rx_ctrl_handle);
    hal_dsi_rx_ctrl_deinit(g_rx_ctrl_handle);

    /* Tear拉低 */
    hal_gpio_init_output(IO_PAD_AP_TE, IO_LVL_LOW);
    panel_display_done = false;
#if RX_WAIT_TEAR_ON
    sg_ap_set_tear_on = false;
#endif

    /* 关闭外设 比如Swire/I2C/Flash 等 */
#if AP_SWIRE_OUTPUT
    hal_swire_deinit();
#endif
#if ANALOG_PWM_OUTPUT
    hal_pwm_deinit();
#endif

#if SHARE_FLASH_ENABLE
    hal_flash_share_mode(false);
#endif

    /* 切换TP18 供电 */
    hal_pwr_set_sleep_mode_power(SLEEP_MODE_POWER);

    if (sleep_mode == PWR_NORMAL_SLEEP_MODE)
    {
        /* normal sleep mode, MCU可以正常工作 */
        hal_gpio_set_ap_reset_int(ENABLE, ap_rstn_pull_high_cb, DETECT_HIGH_LVL);
        hal_pwr_enter_normal_sleep_mode();
		TAU_LOGD("PWR_NORMAL_SLEEP_MODE\n");
    }
    else if (sleep_mode == PWR_STOP_SLEEP_MODE)
    {
		TAU_LOGD("PWR_STOP_SLEEP_MODE\n");

        /* 注册对应 wakeup IO */
        hal_pwr_set_stop_sleep_wakeup_pin(IO_PAD_AP_RSTN, WUP_RISING_EDGE);
        //hal_pwr_set_stop_sleep_wakeup_pin(IO_PAD_AP_SPIS_CSN, WUP_FALLING_EDGE);
        //hal_pwr_set_stop_sleep_wakeup_pin(IO_PAD_TD_INT, WUP_FALLING_EDGE);
        io_pad_e wakeup_io = hal_pwr_enter_stop_sleep_mode();
        if (wakeup_io == IO_PAD_AP_RSTN)
        {
            sg_system_resume = true;
        }
        else
        {
            /* Not impletmented */
            TAU_LOGD("wakeup_io %d FIXME touch wakeup convert to AP\n", wakeup_io);
            hal_gpio_set_ap_reset_int(ENABLE, ap_rstn_pull_high_cb, DETECT_HIGH_LVL);
        }
    }
    else
    {
        /* deep sleep mode,配置AP RSTN 上升沿,TD INT 下降沿唤醒 */
        hal_pwr_enter_deep_sleep_mode(WUP_RISING_EDGE, WUP_FALLING_EDGE);
				TAU_LOGD("PWR_DEEP_SLEEP_MODE\n");
    }

}

/**
* @brief  系统process处理函数,处理待机唤醒等
* @param  none
* @retval none
*/
static void app_system_process(void)
{

    if (sg_system_suspend)
    {
		TAU_LOGD("app_system_process\n");
        /* 系统进入sleep mode */
        app_system_suspend(SLEEP_MODE_SELECT);
        sg_system_suspend = false;
    }

    if (sg_system_resume)
    {
        /* 系统退出sleep mode */
        app_system_resume(SLEEP_MODE_SELECT);
        sg_system_resume = false;
    }

#if TX_START_AFTER_APRST
    if (sg_tx_start_in_process)
    {
        app_mipi_tx_start();
        sg_tx_start_in_process = false;
    }
#endif
}



/**
* @brief  mi12 lite demo 主函数
* @param  none
* @retval none
*/
void google_p8p_demo(void)
{
//	hal_gpio_set_high_impedance(IO_PIN_14);
//	 TAU_LOGD("p6p demo reset flag=%d \n",	hal_pwr_get_reset_flag());

    /* 电源选择,上电只需要选择一次 */
    hal_pwr_set_main_power(MAIN_POWER_SELECT);        /* 切换供电*/
//	if (MAIN_POWER_SELECT == PWR_SEL_VCC)
//	{		
//		while (hal_pwr_get_vcc_power_ready() == false);
//	}
    /* 显示模块初始 */
    app_display_init();

    /* touch 相关模块初始化 */
#if TOUCH_ENABLE
    /* TP 初始化 */
    app_tp_init();
    app_tp_phone_clear_reset_on();
    /* 与屏的TP 模块通讯并初始化 */
    app_tp_transfer_screen_start();
#endif

    TAU_LOGD("p8p demo init done \n");

    while (1)
    {
		
		///hal_dsi_tx_ctrl_set_vpg(1, TX_VPG_H_COLOR, true);
#if TOUCH_ENABLE
        /* 等待屏TP中断上报做TP协议转换,注意接口实现不可阻塞!否则会影响sleep mode */
        app_tp_transfer_screen_int();
#endif
        /* DCS 命令异步处理 */
        while (hal_dsi_rx_ctrl_dcs_async_handler(g_rx_ctrl_handle));

        /* 系统事件处理(sleep mode) */
       app_system_process();
    }
}
#endif
